<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.orionorigin.com
 * @since      1.0.0
 *
 * @package    Otools
 * @subpackage Otools/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Otools
 * @subpackage Otools/admin
 * @author     ORION <help@orionorigin.com>
 */
class Otools_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Otools_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Otools_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/otools-admin.css', array(), $this->version, 'all');
        wp_enqueue_style("o-ui", plugin_dir_url(__FILE__) . 'css/UI.css', array(), $this->version, 'all');
        wp_enqueue_style("o-flexiblegs", plugin_dir_url(__FILE__) . 'css/flexiblegs.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Otools_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Otools_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/otools-admin.js', array('jquery'), $this->version, false);
    }
    
    function generate_demo_install() {
        $demo_type = $_POST["demo_type"];
        $uploads_dir = wp_upload_dir();
        $work_dir = $uploads_dir["basedir"] . "/" . uniqid("cana-demo-import-");
        if (!wp_mkdir_p($work_dir)) {
            echo "Can't create temporary work directory in $work_dir. Are you sure the uploads directory is writeable?";
        }
        $zip_name=  uniqid().".zip";
        
        $demo_file=$work_dir."/$zip_name";
        
        $remote_demo_file_request = $this->get_demo_request_url($demo_type);
        $remote_demo_file = $this->get_demo_file_url($remote_demo_file_request);
        if(!$remote_demo_file)
        {
            $this->clean_mess($work_dir);
            die();
        }
        
        $download_result= $this->download_remote_file($remote_demo_file, $demo_file);
        if($download_result===FALSE)
        {
            echo "Demo file $remote_demo_file download failed. Are you sure you're connected to internet?";
            die();
        }

        WP_Filesystem();
        $unzip_result=unzip_file($demo_file, $work_dir);
        if (is_wp_error($unzip_result))
        {
            echo "Demo package unzip failed.";
            $this->clean_mess($work_dir);
            die();
        }

        ob_start();
        
//        $work_subdir="$work_dir/$demo_type";
        $loading_result= $this->load_demo_database($work_dir);
        if(!$loading_result)
        {
            $this->clean_mess($work_dir, true);
            die();
        }
        
        //We copy the uploads directory
        if(!is_dir($work_dir."/uploads"))
        {
            echo "Uploads directory $work_dir/uploads does not exist in the package.";
            $this->clean_mess($work_dir, true);
            die();
        }
        
        $this->copyr($work_dir."/uploads", $uploads_dir["basedir"]);
        
        //We clean our mess
        $this->clean_mess($work_dir);
        $output = ob_get_contents();
        ob_end_clean();
        if($output)
            echo $output;
        
        echo "Done! Enjoy!";
        die();
        //    return $output;
    }
    
    function get_demo_file_url($remote_demo_file)
    {
        $args = array(
            'timeout'     => 60,
        ); 
        $response = wp_remote_get( $remote_demo_file, $args);
        
        if( is_array($response) ) {
            $body = wp_remote_retrieve_body( $response );
            
            //Sometimes the answer comes with a comment
            $start=strpos($body, "<!--");
            if($start!==FALSE)
            {
                $body=  substr($body, 0, $start);
            }
            $decoded_results=  json_decode(json_decode($body));
            if($decoded_results->success)
            {
                return $decoded_results->message;
            }
            else
            {
                echo $decoded_results->message;
            }
        }
        else if( is_wp_error( $response ) )
        {
            echo $response->get_error_message();
        }
        
        return false;
    }
    
    function clean_mess($work_dir, $clean_buffer=false)
    {
        //We clean our mess
        $this->rrmdir($work_dir);
        if($clean_buffer)
        {
            $output = ob_get_contents();
            ob_end_clean();
            echo $output;
        }
            
    }
    
    function copyr($source, $dest) {
        // Check for symlinks
        if (is_link($source)) {
            return symlink(readlink($source), $dest);
        }

        // Simple copy for a file
        if (is_file($source)) {
            return copy($source, $dest);
        }

        // Make destination directory
        if (!is_dir($dest)) {
            wp_mkdir_p($dest);
        }

        // Loop through the folder
        $dir = dir($source);
        while (false !== $entry = $dir->read()) {
            // Skip pointers
            if ($entry == '.' || $entry == '..') {
                continue;
            }

            // Deep copy directories
            $this->copyr("$source/$entry", "$dest/$entry");
        }

        // Clean up
        $dir->close();
        return true;
    }
    
    private function rrmdir($dir) { 
        if (is_dir($dir)) { 
          $objects = scandir($dir); 
          foreach ($objects as $object) { 
            if ($object != "." && $object != "..") { 
              if (filetype($dir."/".$object) == "dir")
                      $this->rrmdir($dir."/".$object); else unlink($dir."/".$object); 
            } 
          } 
          reset($objects); 
          rmdir($dir); 
        } 
     } 

    private function get_all_urls($string) {
        $regex = '#\bhttps?://[^,\s()<>]+(?:\([\w\d]+\)|([^,[:punct:]\s]|/))#';
        preg_match_all($regex, $string, $matches);
        //return (array_reverse($matches[0]));
        return ($matches[0]);
    }
    
    function utf8_fopen_read($fileName) { 
        
        if (function_exists("iconv") ) {  
            $fc = iconv('windows-1250', 'utf-8', file_get_contents($fileName)); 
        } else {  
            ini_set('mbstring.substitute_character', "none");  
            $fc= mb_convert_encoding(file_get_contents($fileName), 'UTF-8', 'windows-1250');   
        }
        $handle=fopen("php://memory", "rw"); 
        fwrite($handle, $fc); 
        fseek($handle, 0); 
        return $handle; 
    }

    private function load_demo_database($work_dir) {
        global $wpdb;

        $db_file = $work_dir . "/db.sql";
        if(!file_exists($db_file))
        {
            echo "Database file $db_file does not exist in the package.";
            return false;
        }
        $old_siteurl = "";
        $new_siteurl = home_url();
        $handle = $this->utf8_fopen_read($db_file);
        if ($handle) {
            $buffer="";
            while (($line = fgets($handle)) !== false) {
                
                if(
                        empty($line) 
//                        || orion_startsWith($line, "SET ") 
//                        || orion_startsWith($line, "/*!")
                        ||(strpos($line, $wpdb->prefix."users") !== false)
                    )
                    continue;
                
                $buffer.=$line;
                //If the line read is not the end of the sql request
                if(!orion_endsWith($line, ";\n"))
                    continue;

                $col_metas=$wpdb->col_meta;
                $opt_name=$col_metas[$wpdb->options]["option_name"];
                $collation=$opt_name->Collation;
                
                $searches=array("{prefix}", "\r", "\n");
                $replaces=array($wpdb->prefix, "", "");
                if(!empty($collation))
                {
                    array_push($searches, "{collate}");
                    array_push($replaces, $collation);
                }
                else
                {
                    array_push($searches, "COLLATE {collate}");
                    array_push($replaces, "");
                }
                $valid_request = str_replace($searches, $replaces, $buffer);
                
//                echo $valid_request."<==\n";
                $execution_result=$wpdb->query($valid_request);
                    
                if(
                        $execution_result===FALSE 
                        && $wpdb->last_error !== ''
                    )
                {
                    echo "An error occured while loading the database on this request: <br>";
                    echo $valid_request;
                    $wpdb->print_error();
                    return false;
                }

                if (strpos($valid_request, "(1,'siteurl'") !== false) {
                    $urls = $this->get_all_urls($valid_request);
                    //The returned URL returns the correct value plus ,'
                    //Probably an error in the regex
                    $old_siteurl = str_replace("',","", $urls[0]);
                }
                $buffer="";
            }

            fclose($handle);
        } else {
            // error opening the file.
        }
//
//
        //Siteurl replacement
        $sql1 = "UPDATE $wpdb->options SET option_value = replace(option_value, '$old_siteurl', '$new_siteurl') WHERE option_name = 'home' OR option_name = 'siteurl';";
        
        $sql2 = "UPDATE $wpdb->posts SET guid = replace(guid, '$old_siteurl','$new_siteurl');";
        
        $sql3 = "UPDATE $wpdb->posts SET post_content = replace(post_content, '$old_siteurl', '$new_siteurl');";
        
        $sql4 = "UPDATE $wpdb->postmeta SET meta_value = replace(meta_value,'$old_siteurl','$new_siteurl');";
        
        $wpdb->query($sql1);
        $wpdb->query($sql2);
        $wpdb->query($sql3);
        $wpdb->query($sql4);
        
        return true;
        
    }

    private function get_demo_request_url($demo_type, $remote_url=FALSE) {
        $global_theme_options= constant("ORION_CURRENT_THEME_OPTIONS_NAME");
        global $$global_theme_options;
        $theme_options=$$global_theme_options;
        $purchase_code=$theme_options["opt-purchase-code"];
        if(empty($purchase_code))
            echo "The purchase code field is empty. Please enter a valid purchase code.";
        $current_theme=wp_get_theme();
        $site_name = get_bloginfo( 'name' );
        if(empty($site_name))
            $site_name="unamed";
        $site_url=base64_encode(get_home_url());
        $current_theme_name=  $test=  wp_get_theme($current_theme->template);
        $product_name=base64_encode($current_theme_name);
        if(!$remote_url)
            $remote_url="https://www.orionorigin.com/service/odc/v1/check/purchase_code=$purchase_code/product_name=$product_name/demo_id=$demo_type/site_url=$site_url/site_name=$site_name";
        
        return $remote_url;
    }
    
    function download_remote_file($remote_demo_file, $demo_file)
    {
        $download_result=FALSE;
        if( ini_get('allow_url_fopen') )
        {
            $download_result=copy($remote_demo_file, $demo_file);
        }
        else if (function_exists('curl_init')) {
            //File to save the contents to
            $fp = fopen ($demo_file, 'w+');

            $url = $remote_demo_file;

            //Here is the file we are downloading, replace spaces with %20
            $ch = curl_init(str_replace(" ","%20",$url));

            //give curl the file pointer so that it can write to it
            curl_setopt($ch, CURLOPT_FILE, $fp);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            //curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

            $download_result = curl_exec($ch);//get curl response
            if(!$download_result)
            {
                echo "CURL error: ".curl_error($ch).".";
                die();
            }

            //done
            curl_close($ch);
        }
        else
        {
            echo "Unable to download the file the server does not have CURL or allow_url_fopen enabled in the server configuration php.ini file. Please contact your server administrator to make the change before you can download the demo data.";
            die();
        }
        return $download_result;
    }
    
    /**
     * Runs the new version check and upgrade process
     * @return \OTOOLS_Updater
     */
    function get_updater() {
//        do_action('otools_before_init_updater');
        require_once( OTOOLS_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-otools-updater.php' );
        $updater = new OTOOLS_Updater();
        $updater->init();
        require_once( OTOOLS_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-otools-updating-manager.php' );
        $updater->setUpdateManager(new OTOOLS_Updating_Manager(OTOOLS_VERSION, $updater->versionUrl(), OTOOLS_MAIN_FILE));
//        do_action('otools_after_init_updater');
        return $updater;
    }

}
