<?php

class OTOOLS_Updater {
	protected $version_url = 'https://www.orionorigin.com/static/otools-notifier.xml';
	public $title = 'ORION Tools';

	protected $auto_updater = false;
	protected $upgrade_manager = false;
	protected $iframe = false;

	public function init() {
		add_filter('upgrader_pre_download', array($this, 'upgrade_filter_orion'), 10, 4);
		add_action('upgrader_process_complete', array($this, 'remove_temporary_dir'));
	}

	/**
	 * Setter for manager updater.
	 *
	 * @param OTOOLS_Updating_Manager $updater
	 */
	public function setUpdateManager(OTOOLS_Updating_Manager $updater) {
		$this->auto_updater = $updater;
	}
	/**
	 * Getter for manager updater.
	 *
	 * @return OTOOLS_Updating_Manager
	 */
	public function updateManager() {
		return $this->auto_updater;
	}

	/**
	 * Get url for version validation
	 * @return string
	 */
	public function versionUrl() {
		return $this->version_url;
	}
	/**
	 * Downloads new version from ORION server unzips into temporary directory.
	 *
	 * @param $reply
	 * @param $package
	 * @param $updater
	 * @return mixed|string|WP_Error
	 */
	public function upgrade_filter_orion($reply, $package, $updater) {
		global $wp_filesystem;
		if((isset($updater->skin->plugin) && $updater->skin->plugin === OTOOLS_MAIN_FILE) ||
		  (isset($updater->skin->plugin_info) && $updater->skin->plugin_info['Name'] === $this->title)
		) {
			$updater->strings['download_orion'] = __( 'Downloading package from orion...', 'otools' );
			$updater->skin->feedback( 'download_orion' );
//			$package_filename = 'otools.zip';
			$res = $updater->fs_connect( array( WP_CONTENT_DIR ) );
			if ( ! $res ) {
				return new WP_Error( 'no_credentials', __( "Error! Can't connect to filesystem", 'otools' ) );
			}
			$download_file = download_url( 'http://static.orionorigin.com/themes/plugins/otools.zip' );
			if ( is_wp_error( $download_file ) ) {
				return $download_file;
			}
                        
                        $uploads_dir_obj=wp_upload_dir();
			$upgrade_folder = $uploads_dir_obj["basedir"] . '/otools_orion_package';
			if ( is_dir( $upgrade_folder ) ) {
				$wp_filesystem->delete( $upgrade_folder );
			}
                        
                        if (is_file( $download_file ) ) {
                                return $download_file;
                        }
                        return new WP_Error( 'no_credentials', __( 'Error on unzipping package', 'otools' ) );
		}
		return $reply;
	}
	public function remove_temporary_dir() {
		global $wp_filesystem;
		if(is_dir($wp_filesystem->wp_content_dir() . 'uploads/otools_orion_package')) {
			$wp_filesystem->delete($wp_filesystem->wp_content_dir() . 'uploads/otools_orion_package', true);
		}
	}
}