<?php
/**
 * Porto-Novo functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Porto-Novo
 */
if (!function_exists( 'porto_novo_setup' )) :

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function porto_novo_setup() {

        //load TGMPA
        require_once( get_template_directory() . '/inc/class-tgm-plugin-activation.php');

        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on components, use a find and replace
         * to change 'porto-novo' to the name of your theme in all the template files.
         */
        load_theme_textdomain( 'porto-novo', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );
        add_theme_support( 'woocommerce' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );

        add_image_size( 'porto-novo-featured-image', 640, 9999 );

        add_image_size( 'porto-novo-portfolio-featured-image', 800, 9999 );
        add_image_size( 'porto-novo-portfolio-blog-3', 360, 9999 );
        add_image_size( 'porto-novo-portfolio-blog-2', 540, 9999 );

        //Blog sizes
        add_image_size( 'porto-novo-grid-2-left-with-sidebar', 430, 9999 );
        add_image_size( 'porto-novo-grid-2-right-with-sidebar', 430, 9999 );
        add_image_size( 'porto-novo-grid-2-left-no-sidebar', 570, 9999 );
        add_image_size( 'porto-novo-grid-3-left-with-sidebar', 275, 9999 );
        add_image_size( 'porto-novo-grid-3-right-with-sidebar', 275, 9999 );
        add_image_size( 'porto-novo-grid-3-left-no-sidebar', 375, 9999 );
        add_image_size( 'porto-novo-list-1-left-with-sidebar', 880, 9999 );
        add_image_size( 'porto-novo-list-1-right-with-sidebar', 880, 9999 );
        add_image_size( 'porto-novo-list-1-left-no-sidebar', 1170, 9999 );
        add_image_size( 'porto-novo-list-2-left-with-sidebar', 440, 9999 );
        add_image_size( 'porto-novo-list-2-right-with-sidebar', 440, 9999 );
        add_image_size( 'porto-novo-list-2-left-no-sidebar', 590, 9999 );
        add_image_size( 'porto-novo-no-sidebar', 375, 9999 );
        //Blog shortcode sizes
        add_image_size( 'porto-novo-list-1-left-sidebar', 880, 9999 );
        add_image_size( 'porto-novo-list-1-right-sidebar', 880, 9999 );
        add_image_size( 'porto-novo-list-2-left-sidebar', 440, 9999 );
        add_image_size( 'porto-novo-list-2-right-sidebar', 440, 9999 );
        add_image_size( 'porto-novo-list-1-no-sidebar', 375, 9999 );
        add_image_size( 'porto-novo-list-2-no-sidebar', 375, 9999 );
        add_image_size( 'porto-novo-grid-left-sidebar', 430, 9999 );
        add_image_size( 'porto-novo-grid-right-sidebar', 430, 9999 );
        add_image_size( 'porto-novo-grid-no-sidebar', 375, 9999 );



        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'top' => esc_html__( 'Top', 'porto-novo' ),
        ) );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support( 'html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ) );

        /*
         * Enable support for Post Formats.
         * See https://developer.wordpress.org/themes/functionality/post-formats/
         */
        add_theme_support( 'post-formats', array(
            'aside',
            'image',
            'video',
            'audio',
            'quote',
            'link',
            'gallery',
        ) );

        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'porto_novo_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        ) ) );

        define( 'ORION_CURRENT_THEME_OPTIONS_NAME', 'porto_novo_options' );
    }

endif;
add_action( 'after_setup_theme', 'porto_novo_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function porto_novo_content_width() {
    global $content_width;
    if ( ! isset( $content_width ) )
        $content_width = 640;

}

add_action( 'after_setup_theme', 'porto_novo_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function porto_novo_widgets_init() {

    global $porto_novo_options;

    $top_footer_active = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-top-footer', 0 );
    $top_footer_columns = porto_novo_get_proper_value( $porto_novo_options, 'opt-top-footer-columns', 3 );

    register_sidebar( array(
        'name' => esc_html__( 'Sidebar', 'porto-novo' ),
        'id' => 'sidebar-1',
        'description' => __( 'Main Sidebar', 'porto-novo' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget' => '</section>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ) );

    register_sidebar( array(
        'name' => esc_html__( 'WooCommerce Sidebar', 'porto-novo' ),
        'id' => 'woocommerce-sidebar',
        'description' => __( 'WooCommerce Sidebar', 'porto-novo' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget' => '</section>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ) );

    if ($top_footer_active) {
        $args = array(
            /* translators: 1: Column number */
            'name' => esc_html__( 'Top footer column %d', 'porto-novo' ),
            'id' => 'top-footer-column',
            'description' => __('One of the footer sidebar column', 'porto-novo' ),
            'class' => '',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>'
        );

        register_sidebars( $top_footer_columns, $args );
    }
}

add_action( 'widgets_init', 'porto_novo_widgets_init' );

/**
 * Menus Registration.
 */
function porto_novo_menus_registration() {
    register_nav_menus(
            array(
                'extra-menu' => esc_html__( 'Extra Menu', 'porto-novo' )
            )
    );
}

add_action( 'init', 'porto_novo_menus_registration' );

/**
 * Enqueue scripts and styles.
 */
function porto_novo_scripts() {
    global $porto_novo_options;
    wp_enqueue_style( 'porto-novo-style', get_stylesheet_uri() );
    wp_enqueue_script( 'porto-novo-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'porto-novo-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array( 'jquery' ), '20151215', true );
    if (is_singular() && comments_open() && get_option( 'thread_comments' )) {
        wp_enqueue_script( 'comment-reply' );
    }
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/stylesheets/font-awesome/css/font-awesome.min.css' );
    wp_enqueue_style( 'simple-line-icons', get_template_directory_uri() . '/assets/stylesheets/simple-line-icons/css/simple-line-icons.css' );
    wp_enqueue_style( 'themify-icons', get_template_directory_uri() . '/assets/stylesheets/themify-icons.css' );
    wp_enqueue_style( 'jquery-mCustomScrollbar', get_template_directory_uri() . '/assets/stylesheets/jquery.mCustomScrollbar.min.css' );
    wp_enqueue_script( 'jquery-mCustomScrollbar', get_template_directory_uri() . '/assets/js/jquery.mCustomScrollbar.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'masonry-pkgd', get_template_directory_uri() . '/assets/js/masonry.pkgd.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'jquery-mixitup', get_template_directory_uri() . '/assets/js/jquery.mixitup.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_style( 'jquery-bxslider', get_template_directory_uri() . '/assets/stylesheets/jquery.bxslider.css' );
    wp_enqueue_script( 'jquery-bxslider', get_template_directory_uri() . '/assets/js/jquery.bxslider.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'typed', get_template_directory_uri() . '/assets/js/typed.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'imagesloaded-pkgd', get_template_directory_uri() . '/assets/js/imagesloaded.pkgd.min.js', array( 'jquery' ), '20151215', true );
    wp_register_script( 'porto-novo-main', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery', 'imagesloaded-pkgd' ) );

    $translation_placeholder = array(
        'usernamePlaceholder' => __( 'Username', 'porto-novo' ),
        'passwordPlaceholder' => __( 'Password', 'porto-novo' ),
    );

    wp_localize_script( 'porto-novo-main', 'placeHolderForTopBar', $translation_placeholder );
    wp_enqueue_script( 'porto-novo-main' );
    $custom_js = porto_novo_get_proper_value( $porto_novo_options, 'opt_js_editor' );
    if ($custom_js) {
        wp_add_inline_script( 'porto-novo-main', $custom_js );
    }
}

add_action( 'wp_enqueue_scripts', 'porto_novo_scripts' );

function porto_novo_enqueue_top_scripts() {

    global $porto_novo_options;

    wp_enqueue_style( 'porto-novo-main-style', get_template_directory_uri() . '/assets/stylesheets/style.css' );

    $custom_css = porto_novo_get_proper_value( $porto_novo_options, 'opt_css_editor' );
    if ($custom_css) {
        wp_add_inline_style( 'porto-novo-main-style', $custom_css );
    }
}

add_action( 'wp_enqueue_scripts', 'porto_novo_enqueue_top_scripts' );

function porto_novo_add_font_awesome_to_reduc_panel() {
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/stylesheets/font-awesome/css/font-awesome.min.css', array(), time(), 'all' );
}

add_action( 'redux/page/porto_novo_options/enqueue', 'porto_novo_add_font_awesome_to_reduc_panel' );

/**
 * Registers an editor stylesheet for the theme.
 */
function porto_novo_wpdocs_theme_add_editor_styles() {
    add_editor_style( get_template_directory_uri() . '/assets/stylesheets/editor-style.css' );
}

add_action( 'admin_init', 'porto_novo_wpdocs_theme_add_editor_styles' );

/**
 * Put the comment fields bellow the comments list
 * @param array $fields
 * @return type
 */
function porto_novo_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields[ 'comment' ];
    unset( $fields[ 'comment' ] );
    $fields[ 'comment' ] = $comment_field;
    return $fields;
}

add_filter( 'comment_form_fields', 'porto_novo_move_comment_field_to_bottom' );

/**
 * Set comment areaa fields
 * @param type $comment
 * @param type $args
 * @param type $depth
 */
function porto_novo_comments( $comment, $args, $depth ) {
    ?>
    <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
        <div id="comment-<?php comment_ID(); ?>" class="comment-container">

    <?php echo get_avatar( $comment, $size = '70' ); ?>
            <div class="comment-text-wrap">

                <cite><?php echo get_comment_author_link() ?></cite>

            <?php if ('0' === $comment->comment_approved) : ?>
                    <em><?php esc_html_e( 'Your comment is awaiting moderation.', 'porto-novo' ) ?></em>
                    <br />
    <?php endif; ?>

                <?php comment_text() ?>

                <div class="comment-date"><?php
                printf(
                        /* translators: 1: Comment date count 2: Comment time */
                        esc_html__( '%1$s at %2$s', 'porto-novo' ), get_comment_date(), get_comment_time() )
                ?><?php edit_comment_link( esc_html__( '(Edit)', 'porto-novo' ), '  ', '' ) ?></div>

                    <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args[ 'max_depth' ] ) ) ) ?>
            </div>
        </div>
                <?php
            }

            function porto_novo_search_default_title( $title, $instance = "", $id_base = "" ) {

                if ('search' === $id_base && '' === $title) {
                    return esc_html__( 'Search', 'porto-novo' );
                } else {
                    return $title;
                }
            }

            add_filter( 'widget_title', 'porto_novo_search_default_title', 10, 3 );

            function porto_novo_get_post_format_raw_url() {
                if (!preg_match( "/(?:http|https)?(?:\:\/\/)?(?:www.)?(([A-Za-z0-9-]+\.)*[A-Za-z0-9-]+\.[A-Za-z]+)(?:\/.*)?/im", get_the_content(), $matches )) {
                    return false;
                }
                return esc_url_raw( $matches[ 0 ] );
            }

            function porto_novo_get_post_format_link() {
                if (!preg_match( "/<a\s[^>]*href=(\"??)([^\" >]*?)\\1[^>]*>(.*)<\/a>/siU", get_the_content(), $matches )) {
                    return false;
                }
                return $matches[ 0 ];
            }

// Breadcrumbs
            function porto_novo_breadcrumbs() {

                // Settings
                $separator = '/';
                $breadcrums_id = 'breadcrumbs';
                $breadcrums_class = 'breadcrumbs';
                $home_title = esc_html( 'Home', 'porto-novo' );

                // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
                $custom_taxonomy = 'product_cat';

                // Get the query & post information
                global $post, $wp_query;

                // Do not display on the homepage
                if (!is_front_page()) {

                    // Build the breadcrums
                    echo '<ul id="' . esc_attr( $breadcrums_id ) . '" class="' . esc_attr( $breadcrums_class ) . '">';

                    // Home page
                    echo '<li class="item-home"><a class="bread-link bread-home" href="' . esc_url( get_home_url( "/" ) ) . '" title="' . esc_attr( $home_title ) . '">' . esc_html( $home_title ) . '</a></li>';
                    echo '<li class="separator separator-home"> ' . esc_html( $separator ) . ' </li>';

                    if (is_archive() && !is_tax() && !is_category() && !is_tag()) {

                        echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . post_type_archive_title( '', false ) . '</strong></li>';
                    } elseif (is_archive() && is_tax() && !is_category() && !is_tag()) {

                        // If post is a custom post type
                        $post_type = get_post_type();

                        // If it is a custom post type display name and link
                        if ('post' !== $post_type) {

                            $post_type_object = get_post_type_object( $post_type );
                            $post_type_archive = get_post_type_archive_link( $post_type );

                            echo '<li class="item-cat item-custom-post-type-' . esc_attr( $post_type ) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr( $post_type ) . '" href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_html( $post_type_object->labels->name ) . '</a></li>';
                            echo '<li class="separator"> ' . esc_html( $separator ) . ' </li>';
                        }

                        $custom_tax_name = get_queried_object()->name;
                        echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . esc_html( $custom_tax_name ) . '</strong></li>';
                    } elseif (is_single()) {

                        // If post is a custom post type
                        $post_type = get_post_type();

                        // If it is a custom post type display name and link
                        if ('post' !== $post_type) {

                            $post_type_object = get_post_type_object( $post_type );
                            $post_type_archive = get_post_type_archive_link( $post_type );

                            echo '<li class="item-cat item-custom-post-type-' . esc_attr( $post_type ) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr( $post_type ) . '" href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_html( $post_type_object->labels->name ) . '</a></li>';
                            echo '<li class="separator"> ' . esc_html( $separator ) . ' </li>';
                        }

                        // Get post category info
                        $category = get_the_category();

                        if (!empty( $category )) {

                            // Get last category post is in
                            $category_values = array_values( $category );

                            $last_category = end( $category_values );

                            // Get parent any categories and create array
                            $get_cat_parents = rtrim( get_category_parents( $last_category->term_id, true, ',' ), ',' );
                            $cat_parents = explode( ',', $get_cat_parents );

                            // Loop through parent categories and store in variable $cat_display
                            $cat_display = '';
                            foreach ($cat_parents as $parents) {
                                $cat_display .= '<li class="item-cat">' . $parents . '</li>';
                                $cat_display .= '<li class="separator"> ' . $separator . ' </li>';
                            }
                        }

                        // If it's a custom post type within a custom taxonomy
                        $taxonomy_exists = taxonomy_exists( $custom_taxonomy );
                        if (empty( $last_category ) && !empty( $custom_taxonomy ) && $taxonomy_exists) {

                            $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
                            if (isset( $taxonomy_terms[ 0 ] ) && property_exists( $taxonomy_terms[ 0 ], 'term_id' )) {
                                $cat_id = $taxonomy_terms[ 0 ]->term_id;
                                $cat_nicename = $taxonomy_terms[ 0 ]->slug;
                                $cat_link = get_term_link( $taxonomy_terms[ 0 ]->term_id, $custom_taxonomy );
                                $cat_name = $taxonomy_terms[ 0 ]->name;
                            }
                        }

                        // Check if the post is in a category
                        if (!empty( $last_category )) {
                            echo wp_kses_post( $cat_display );
                            echo '<li class="item-current item-' . esc_attr( $post->ID ) . '"><strong class="bread-current bread-' . esc_attr( $post->ID ) . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';

                            // Else if post is in a custom taxonomy
                        } elseif (!empty( $cat_id )) {

                            echo '<li class="item-cat item-cat-' . esc_attr( $cat_id ) . ' item-cat-' . esc_attr( $cat_nicename ) . '"><a class="bread-cat bread-cat-' . esc_attr( $cat_id ) . ' bread-cat-' . esc_attr( $cat_nicename ) . '" href="' . esc_url( $cat_link ) . '" title="' . esc_attr( $cat_name ) . '">' . esc_html( $cat_name ) . '</a></li>';
                            echo '<li class="separator"> ' . esc_html( $separator ) . ' </li>';
                            echo '<li class="item-current item-' . esc_attr( $post->ID ) . '"><strong class="bread-current bread-' . esc_attr( $post->ID ) . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';
                        } else {

                            echo '<li class="item-current item-' . esc_attr( $post->ID ) . '"><strong class="bread-current bread-' . esc_attr( $post->ID ) . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';
                        }
                    } elseif (is_category()) {

                        // Category page
                        echo '<li class="item-current item-cat"><strong class="bread-current bread-cat">' . single_cat_title( '', false ) . '</strong></li>';
                    } elseif (is_page()) {

                        // Standard page
                        if ($post->post_parent) {

                            // If child page, get parents
                            $anc = get_post_ancestors( $post->ID );

                            // Get parents in the right order
                            $anc = array_reverse( $anc );

                            // Parent page loop
                            $parents = "";
                            foreach ($anc as $ancestor) {
                                $parents .= '<li class="item-parent item-parent-' . $ancestor . '"><a class="bread-parent bread-parent-' . $ancestor . '" href="' . esc_url( get_permalink( $ancestor ) ) . '" title="' . get_the_title( $ancestor ) . '">' . get_the_title( $ancestor ) . '</a></li>';
                                $parents .= '<li class="separator separator-' . $ancestor . '"> ' . $separator . ' </li>';
                            }

                            // Display parent pages
                            echo wp_kses_post( $parents );

                            // Current page
                            echo '<li class="item-current item-' . esc_attr( $post->ID ) . '"><strong title="' . get_the_title() . '"> ' . get_the_title() . '</strong></li>';
                        } else {

                            // Just display current page if not parents
                            echo '<li class="item-current item-' . esc_attr( $post->ID ) . '"><strong class="bread-current bread-' . esc_attr( $post->ID ) . '"> ' . get_the_title() . '</strong></li>';
                        }
                    } elseif (is_tag()) {

                        // Tag page
                        // Get tag information
                        $term_id = get_query_var( 'tag_id' );
                        $taxonomy = 'post_tag';
                        $args = 'include=' . $term_id;
                        $terms = get_terms( $taxonomy, $args );
                        $get_term_id = $terms[ 0 ]->term_id;
                        $get_term_slug = $terms[ 0 ]->slug;
                        $get_term_name = $terms[ 0 ]->name;

                        // Display the tag name
                        echo '<li class="item-current item-tag-' . esc_attr( $get_term_id ) . ' item-tag-' . esc_attr( $get_term_slug ) . '"><strong class="bread-current bread-tag-' . esc_attr( $get_term_id ) . ' bread-tag-' . esc_attr( $get_term_slug ) . '">' . esc_html( $get_term_name ) . '</strong></li>';
                    } elseif (is_day()) {

                        // Day archive
                        // Year link
                        echo '<li class="item-year item-year-' . esc_attr( get_the_time( 'Y' ) ) . '"><a class="bread-year bread-year-' . esc_attr( get_the_time( 'Y' ) ) . '" href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '" title="' . esc_attr( get_the_time( 'Y' ) ) . '">' . esc_html( get_the_time( 'Y' ) ) . ' Archives</a></li>';
                        echo '<li class="separator separator-' . esc_attr( get_the_time( 'Y' ) ) . '"> ' . esc_html( $separator ) . ' </li>';

                        // Month link
                        echo '<li class="item-month item-month-' . esc_attr( get_the_time( 'm' ) ) . '"><a class="bread-month bread-month-' . esc_attr( get_the_time( 'm' ) ) . '" href="' . esc_url( get_month_link( get_the_time( 'Y' ) ), get_the_time( 'm' ) ) . '" title="' . esc_attr( get_the_time( 'M' ) ) . '">' . esc_html( get_the_time( 'M' ) ) . ' Archives</a></li>';
                        echo '<li class="separator separator-' . esc_attr( get_the_time( 'm' ) ) . '"> ' . esc_html( $separator ) . ' </li>';

                        // Day display
                        echo '<li class="item-current item-' . esc_attr( get_the_time( 'j' ) ) . '"><strong class="bread-current bread-' . esc_attr( get_the_time( 'j' ) ) . '"> ' . esc_html( get_the_time( 'jS' ) ) . ' ' . esc_html( get_the_time( 'M' ) ) . ' Archives</strong></li>';
                    } elseif (is_month()) {

                        // Month Archive
                        // Year link
                        echo '<li class="item-year item-year-' . esc_attr( get_the_time( 'Y' ) ) . '"><a class="bread-year bread-year-' . esc_attr( get_the_time( 'Y' ) ) . '" href="' . esc_url( get_year_link( get_the_time( 'Y' ) ) ) . '" title="' . esc_attr( get_the_time( 'Y' ) ) . '">' . esc_html( get_the_time( 'Y' ) ) . ' Archives</a></li>';
                        echo '<li class="separator separator-' . esc_attr( get_the_time( 'Y' ) ) . '"> ' . esc_html( $separator ) . ' </li>';

                        // Month display
                        echo '<li class="item-month item-month-' . esc_attr( get_the_time( 'm' ) ) . '"><strong class="bread-month bread-month-' . esc_attr( get_the_time( 'm' ) ) . '" title="' . esc_attr( get_the_time( 'M' ) ) . '">' . esc_html( get_the_time( 'M' ) ) . ' Archives</strong></li>';
                    } elseif (is_year()) {

                        // Display year archive
                        echo '<li class="item-current item-current-' . esc_attr( get_the_time( 'Y' ) ) . '"><strong class="bread-current bread-current-' . esc_attr( get_the_time( 'Y' ) ) . '" title="' . esc_attr( get_the_time( 'Y' ) ) . '">' . esc_html( get_the_time( 'Y' ) ) . ' Archives</strong></li>';
                    } elseif (is_author()) {

                        // Auhor archive
                        // Get the author information
                        global $author;
                        $userdata = get_userdata( $author );

                        // Display author name
                        echo '<li class="item-current item-current-' . esc_attr( $userdata->user_nicename ) . '"><strong class="bread-current bread-current-' . esc_attr( $userdata->user_nicename ) . '" title="' . esc_attr( $userdata->display_name ) . '">' . 'Author: ' . esc_html( $userdata->display_name ) . '</strong></li>';
                    } elseif (get_query_var( 'paged' )) {

                        // Paginated archives
                        echo '<li class="item-current item-current-' . esc_attr( get_query_var( 'paged' ) ) . '"><strong class="bread-current bread-current-' . esc_attr( get_query_var( 'paged' ) ) . '" title="Page ' . esc_attr( get_query_var( 'paged' ) ) . '">' . esc_html__( 'Page', 'porto-novo' ) . ' ' . esc_html( get_query_var( 'paged' ) ) . '</strong></li>';
                    } elseif (is_search()) {

                        // Search results page
                        echo '<li class="item-current item-current-' . get_search_query() . '"><strong class="bread-current bread-current-' . get_search_query() . '" title="'.esc_html('Search results for: ', 'porto-novo') . get_search_query() . '">'.esc_html('Search results for: ', 'porto-novo') . get_search_query() . '</strong></li>';
                    } elseif (is_404()) {

                        // 404 page
                        echo '<li>' . 'Error 404' . '</li>';
                    }

                    echo '</ul>';
                }
            }

            function porto_novo_get_post_thumb() {

                $post_id = get_the_ID();
                $post_format = get_post_format();
                $meta = get_post_meta( $post_id, "porto-novo", true );

                $post_thumb = "";
                switch ($post_format) {

                    case 'quote':
                        global $post;
                        $regexp = "<blockquote>(.*)<\/blockquote>";
                        $input = get_the_content();
                        if (preg_match_all( "/$regexp/siU", $input, $matches )) {
                            $post_thumb = $matches[ 0 ][ 0 ];
                        }
                        break;

                    case 'link':
                        global $post;
                        $regexp = "<a\s[^>]*href=(\"??)([^\" >]*?)\\1[^>]*>(.*)<\/a>";
                        $input = get_the_content();
                        if (preg_match_all( "/$regexp/siU", $input, $matches )) {
                            $post_thumb = "<div class='post-thumb'>" . $matches[ 0 ][ 0 ] . "</div>";
                        }
                        break;

                    case 'video':
                    case 'audio':
                        global $post;
                        global $wp_embed;
                        $pattern = get_shortcode_regex( array( "embed", "audio", "wpvideo" ) );
                        $matches = array();
                        preg_match( "/$pattern/s", get_the_content(), $matches );
                        if (!empty( $matches )) {
                            $post_thumb = do_shortcode( $matches[ 0 ] );
                        } else {
                            $post_thumb_url = porto_novo_get_post_format_raw_url();
                            if ($post_thumb_url) {
                                $post_thumb = wp_oembed_get( $post_thumb_url );
                            }
                        }
                        break;

                    case 'image':
                        $url = porto_novo_grab_first_image();
                        if ($url)
                            $post_thumb = '<img src="' . esc_attr( $url ) . '" alt="' . esc_html__( 'Post thumbnail', 'porto-novo' ) . '" >';
                    case 'gallery':
                        global $post;
                        $pattern = get_shortcode_regex( array( "gallery" ) );
                        $matches = array();
                        preg_match( "/$pattern/s", get_the_content(), $matches );
                        if (!empty( $matches )) {
                            $post_thumb = do_shortcode( $matches[ 0 ] );
                        } else {

                        }

                        break;

                    default:
                        global $post;
                        $url = wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) );
                        if ($url)
                            $post_thumb = '<img src="' . esc_attr( $url ) . '" alt="' . esc_html__( 'Post thumbnail', 'porto-novo' ) . '" >';

                        break;
                }

                return $post_thumb;
            }

            /**
             * Recommanded plugins
             */
            add_action( 'tgmpa_register', 'porto_novo_register_required_plugins' );

            function porto_novo_register_required_plugins() {

                $plugins = array(
                    array(
                        'name' => esc_html__( 'Redux Framework', 'porto-novo' ),
                        'slug' => 'redux-framework',
                        'required' => true,
                    ),
                    array(
                        'name' => esc_html__( 'ORION Tools', 'porto-novo' ),
                        'slug' => 'otools',
                        'required' => true,
                        'source' => get_template_directory() . '/plugins/otools.zip',
                        'version' => '1.3',
                    ),
                    array(
                        'name' => esc_html__( 'WooCommerce', 'porto-novo' ),
                        'slug' => 'woocommerce',
                        'required' => false,
                    ),
                    array(
                        'name' => esc_html__( 'WOOF - WooCommerce Products Filter', 'porto-novo' ),
                        'slug' => 'woocommerce-products-filter',
                        'required' => false,
                        'source' => get_template_directory() . '/plugins/woocommerce-products-filter.zip',
                    ),
                    array(
                        'name' => esc_html__( 'Contact form 7', 'porto-novo' ),
                        'slug' => 'contact-form-7',
                        'required' => false,
                    ),
                    array(
                        'name' => esc_html__( 'YITH WooCommerce Wishlist', 'porto-novo' ),
                        'slug' => 'yith-woocommerce-wishlist',
                        'required' => false,
                    )
                    , array(
                        'name' => esc_html__( 'WPBakery Page Builder', 'porto-novo' ),
                        'slug' => 'js_composer',
                        'required' => false,
                        'source' => get_template_directory() . '/plugins/js_composer.zip',
                        'version' => '5.7',

                    ),
                    array(
                        'name' => esc_html__( 'Revolution Slider', 'porto-novo' ),
                        'slug' => 'rev_slider',
                        'required' => false,
                        'source' => get_template_directory() . '/plugins/revslider.zip',
                        'version' => '5.4.8.1',
                    ),
                    array(
                        'name' => esc_html__( 'WooCommerce Products Designer', 'porto-novo' ),
                        'slug' => 'woocommerce-product-designer',
                        'required' => true,
                        'source' => get_template_directory() . '/plugins/woocommerce-product-designer.zip',
                        'version' => '5.5.1',
                    ),
                    array(
                        'name' => esc_html__( 'UI Elements for WordPress', 'porto-novo' ),
                        'slug' => 'uie',
                        'required' => true,
                        'source' => get_template_directory() . '/plugins/uie.zip',
                    ),
                    array(
                        'name' => esc_html__( 'WP Google Maps', 'porto-novo' ),
                        'slug' => 'wp-google-maps',
                        'required' => false,
                    ),
                );

                $config = array(
                    'id' => 'porto-povo', // Unique ID for hashing notices for multiple instances of TGMPA.
                    'default_path' => '', // Default absolute path to bundled plugins.
                    'menu' => 'tgmpa-install-plugins', // Menu slug.
                    'has_notices' => true, // Show admin notices or not.
                    'dismissable' => true, // If false, a user cannot dismiss the nag message.
                    'dismiss_msg' => '', // If 'dismissable' is false, this message will be output at top of nag.
                    'is_automatic' => false, // Automatically activate plugins after installation or not.
                    'message' => '', // Message to output right before the plugins table.
                );

                tgmpa( $plugins, $config );
            }

            function porto_novo_grab_first_image() {
                global $post, $posts;
                $first_img = '';
                $output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );
                $first_img = $matches [ 1 ] [ 0 ];

                if (empty( $first_img )) { //return false
                    $first_img = false;
                }
                return $first_img;
            }

            function porto_novo_get_logo() {
                global $porto_novo_options;
                $porto_novo_logo_options = porto_novo_get_proper_value( $porto_novo_options, 'opt-upload-logo-image', array() );

                $porto_novo_header_logo = porto_novo_get_proper_value( $porto_novo_logo_options, 'url' );

                $porto_novo_default_logo = get_template_directory_uri() . '/assets/images/01_porto-novo-logo.png';

                echo'<p class="logo"><a href="' . esc_url( home_url( '/' ) ) . '" rel="home">';

                if (!empty( $porto_novo_header_logo )) {
                    echo"<img src='" . esc_attr( $porto_novo_header_logo ) . "' alt='logo" . esc_attr( get_bloginfo( 'name' ) ) . "'>";
                } else {
                    echo"<img src='" . esc_attr( $porto_novo_default_logo ) . "' alt='logo" . esc_attr( get_bloginfo( 'name' ) ) . "'>";
                }
                echo"</a></p>";
            }

            /**
             * Maintenance mode
             */
            function porto_novo_render_coming_soon( $template ) {
                if (!porto_novo_is_coming_soon_active()) {
                    return $template;
                } else {
                    $template = locate_template( array( 'coming-soon.php' ) );
                    return $template;
                }
            }

            add_action( 'template_include', 'porto_novo_render_coming_soon' );

            function porto_novo_is_coming_soon_active() {
                global $porto_novo_options;
                $coming_soon_mode_is_active = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-coming-soon', '0' );
                if ('0' === $coming_soon_mode_is_active || ('1' === $coming_soon_mode_is_active && is_user_logged_in())) {
                    return false;
                } else {
                    return true;
                }
            }

            function porto_novo_is_active_sidebar( $is_active_sidebar ) {
                global $porto_novo_options;
                $porto_novo_is_active_sidebar = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-sidebar', '1' );
                $porto_novo_is_active_sidebar = apply_filters( "porto_novo_is_active_sidebar", $porto_novo_is_active_sidebar );
                if ('1' === $porto_novo_is_active_sidebar && $is_active_sidebar) {
                    return true;
                } else {
                    return false;
                }
            }

            add_filter( 'is_active_sidebar', 'porto_novo_is_active_sidebar' );

            function porto_novo_get_home_slider_posts_id() {
                global $porto_novo_options;
                $portonovo_slider_posts = porto_novo_get_proper_value( $porto_novo_options, 'opt-home-page-slider-posts', "" );
                return $portonovo_slider_posts;
            }

            /*             *
             *
             * @global type $page
             * @global type $numpages
             * @global type $multipage
             * @global type $more
             * @global type $pagenow
             * @param type $args
             * @return string
             */

            function porto_novo_add_next_and_number( $args ) {
                if ('next_and_number' === $args[ 'next_or_number' ]) {
                    global $page, $numpages, $multipage, $more, $pagenow;
                    $args[ 'next_or_number' ] = 'number';
                    $prev = '';
                    $next = '';
                    if ($multipage) {
                        if ($more) {
                            $i = $page - 1;
                            if ($i && $more) {
                                $prev .= _wp_link_page( $i );
                                $prev .= $args[ 'link_before' ] . $args[ 'previouspagelink' ] . $args[ 'link_after' ] . '</a>';
                            }
                            $i = $page + 1;
                            if ($i <= $numpages && $more) {
                                $next .= _wp_link_page( $i );
                                $next .= $args[ 'link_before' ] . $args[ 'nextpagelink' ] . $args[ 'link_after' ] . '</a>';
                            }
                        }
                    }
                    $args[ 'before' ] = $args[ 'before' ] . $prev;
                    $args[ 'after' ] = $next . $args[ 'after' ];
                }
                return $args;
            }

            add_filter( 'wp_link_pages_args', 'porto_novo_add_next_and_number' );

            function porto_novo_get_wishlist_buttons() {
                if (function_exists( 'yith_wishlist_install' )) {
                    echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
                }
            }

            add_action( 'woocommerce_shop_loop_item_title', 'porto_novo_get_wishlist_buttons', 10 );

            function porto_novo_loop_columns() {
                return 3;
            }

            add_filter( 'loop_shop_columns', 'porto_novo_loop_columns' );

            function porto_novo_woocommerce_sidebar() {
                if (!is_active_sidebar( 'woocommerce-sidebar' )) {
                    return;
                }
                ?>

        <aside id="secondary" class="shop-widget-area">
        <?php dynamic_sidebar( 'woocommerce-sidebar' ); ?>
        </aside>

        <?php
    }

    function porto_novo_content_after_addtocart() {
        global $product, $product_id, $product_type, $link_classes;

        if (porto_novo_woocommerce_version_check()) {
            $product_type = $product->product_type;
            $product_id = $product->id;
        } else {
            $product_type = $product->get_type();
            $product_id = $product->get_id();
        }


        if (function_exists( 'yith_wishlist_install' )):
            ?>
            <a href="<?php echo esc_url( add_query_arg( 'add_to_wishlist', $product_id ) ) ?>" title=" <?php esc_html_e( "Add to whishlist", 'porto-novo' ) ?>" rel="nofollow" data-product-id="<?php echo esc_attr( $product_id ) ?>" data-product-type="<?php echo esc_attr( $product_type ) ?>" class=" after-add-to-cart-button add_to_wishlist yith-wcwl-add-to-wishlist add-to-wishlist-<?php echo esc_attr( $product_id ) ?>" >
                <i class="ti-heart"></i>
            </a>
            <?php
        endif;
    }

    add_action( 'woocommerce_after_add_to_cart_button', 'porto_novo_content_after_addtocart' );

    function porto_novo_woocommerce_version_check( $version = '3.0.0' ) {
        if (function_exists( "WC" ) && ( version_compare( WC()->version, $version, "<" )))
            return true;
        return false;
    }

    function porto_novo_load_wp_admin_style() {
        wp_enqueue_script( 'porto-novo-wp-admin-script', get_template_directory_uri() . '/assets/js/admin-scripts.js' );
    }

    add_action( 'admin_enqueue_scripts', 'porto_novo_load_wp_admin_style' );

    function porto_novo_content_area_class( $porto_novo_content_area_class ) {
        $sidebar_name = "sidebar-1";
        if (function_exists( "is_woocommerce" ) && (is_woocommerce() || is_cart() || is_checkout())) {
            $sidebar_name = "woocommerce-sidebar";
        }
        if (is_active_sidebar( $sidebar_name )) {
            $porto_novo_content_area_class .= " content-area with-sidebar ";
        } else {
            $porto_novo_content_area_class .= " content-area no-sidebar ";
        }
        return $porto_novo_content_area_class;
    }

    add_filter( 'porto_novo_content_area_class', 'porto_novo_content_area_class' );

    function porto_novo_get_single_product_nav() {

        if (is_singular()) {
            ?>
            <div class='product-nav-wrap' >
                <nav class="single-product-nav">
                    <span class="nav-previous alignleft"><?php previous_post_link( '%link', '<i class="fa fa-chevron-left"></i>', FALSE ); ?></span>
                    <span class="nav-next alignright"><?php next_post_link( '%link', '<i class="fa fa-chevron-right"></i>', FALSE ); ?></span>
                </nav>
            </div>
            <?php
        }
    }

    add_action( 'woocommerce_single_product_summary', 'porto_novo_get_single_product_nav', 6, 0 );

    function porto_novo_get_gallery_attachments_ids() {
        global $post;

        $post_content = $post->post_content;
        preg_match( '/\[gallery.*ids=.(.*).\]/', $post_content, $ids );
        $images_id=array();
        if(isset($ids[ 1 ]))
            $images_id = explode( ",", $ids[ 1 ] );

        return $images_id;
    }

    function porto_novo_page_navi() {
        global $wp_query;
        $bignum = 999999999;
        if ($wp_query->max_num_pages <= 1)
            return;
        echo '<nav class="pagination">';
        echo wp_kses_post( paginate_links( array(
            'base' => str_replace( $bignum, '%#%', esc_url( get_pagenum_link( $bignum ) ) ),
            'format' => '',
            'current' => max( 1, get_query_var( 'paged' ) ),
            'total' => $wp_query->max_num_pages,
            'prev_text' => esc_html__( 'Previous', 'porto-novo' ),
            'next_text' => esc_html__( 'Next', 'porto-novo' ),
            'type' => 'list',
            'end_size' => 3,
            'mid_size' => 3
        ) ) );
        echo '</nav>';
    }

    /**
     * Custom template tags for this theme.
     */
    require get_template_directory() . '/inc/template-tags.php';

    /**
     * Custom functions that act independently of the theme templates.
     */
    require get_template_directory() . '/inc/extras.php';

    /**
     * Customizer additions.
     */
    require get_template_directory() . '/inc/customizer.php';

    /**
     * Load Jetpack compatibility file.
     */
    require get_template_directory() . '/inc/jetpack.php';

    /*
     * load redux framework
     */
    require_once (get_template_directory() . '/inc/redux/porto-novo-config.php');

    /*
     * load google fonts
     */
    require_once (get_template_directory() . '/inc/google-font.php');

    /**
     * Register page meta box(es).
     */
    function porto_novo_register_page_meta_boxes() {
        add_meta_box( 'porto_novo_page_metabox', esc_html__( 'Page Settings', 'porto-novo' ), 'porto_novo_get_page_meta_boxes', 'page' );
    }

    add_action( 'add_meta_boxes', 'porto_novo_register_page_meta_boxes' );

    function porto_novo_get_page_meta_boxes( $post ) {
        ?>
        <div class='block-form'>
            <?php
            $begin = array(
                'type' => 'sectionbegin',
                'id' => 'porto-novo-page-container',
            );
            $sidebar = array(
                'title' => __( 'Sidebar', 'porto-novo' ),
                'name' => 'porto-novo-page[sidebar-position]',
                'type' => 'radio',
                'options' => array(
                    "left-sidebar" => __( 'Left Sidebar', 'porto-novo' ),
                    "right-sidebar" => __( 'Right Sidebar', 'porto-novo' ),
                    "no-sidebar" => __( 'No Sidebar', 'porto-novo' ),
                ),
                'desc' => __( 'Sidebar Position', 'porto-novo' ),
                'default' => 'left-sidebar',
            );

            $layout = array(
                'title' => __( 'Layout', 'porto-novo' ),
                'name' => 'porto-novo-page[layout]',
                'type' => 'radio',
                'options' => array(
                    "boxed" => __( 'Boxed', 'porto-novo' ),
                    "full-width" => __( 'Full Width', 'porto-novo' ),
                ),
                'desc' => __( 'Page Layout', 'porto-novo' ),
                'default' => 'boxed',
            );

            $header = array(
                'title' => __( 'Show title section', 'porto-novo' ),
                'name' => 'porto-novo-page[show-title]',
                'type' => 'radio',
                'options' => array(
                    0 => __( 'No', 'porto-novo' ),
                    1 => __( 'Yes', 'porto-novo' ),
                ),
                'desc' => __( 'Whether or not to disable the page title section', 'porto-novo' ),
                'default' => 1,
            );

            $end = array( 'type' => 'sectionend' );
            $settings = array(
                $begin,
                $sidebar,
                $layout,
                $header,
            );

            if (class_exists( 'RevSlider' )) {
                $rev_slider = new RevSlider();
                $sliders = $rev_slider->getAllSliderAliases();
                $sliders_arr = array( "" => "None" );
                foreach ($sliders as $slider) {
                    $sliders_arr[ $slider ] = $slider;
                }
                $sliders_select = array(
                    'title' => __( 'Revolution Slider', 'porto-novo' ),
                    'name' => 'porto-novo-page[revo-slider]',
                    'type' => 'select',
                    'options' => $sliders_arr,
                    'desc' => __( 'Choose a revolution slider to show in the page', 'porto-novo' ),
                );
                array_push( $settings, $sliders_select );
            }

            $slider_post_ids = porto_novo_get_home_slider_posts_id();

            if ($slider_post_ids) {
                $default_theme_slider = array(
                    'title' => __( 'Show default theme slider', 'porto-novo' ),
                    'name' => 'porto-novo-page[default-slider]',
                    'type' => 'radio',
                    'options' => array(
                        0 => __( 'No', 'porto-novo' ),
                        1 => __( 'Yes', 'porto-novo' ),
                    ),
                    'desc' => __( 'Whether or not to use the theme\'s default slider in the page', 'porto-novo' ),
                    'default' => 0,
                );
                array_push( $settings, $default_theme_slider );
            }

            array_push( $settings, $end );

            echo orion_admin_fields( $settings );
            wp_nonce_field( 'porto-novo-nonce', 'porto-novo-nonce' );
            ?>
        </div>
        <?php
    }

    /**
     * Save meta box content.
     *
     * @param int $post_id Post ID
     */
    function porto_novo_save_page_meta_boxes( $post_id ) {
        if (isset( $_POST[ 'porto-novo-nonce' ] ) && wp_verify_nonce( $_REQUEST[ 'porto-novo-nonce' ], 'porto-novo-nonce' ) && isset( $_POST[ 'porto-novo-page' ] )) {
            $porto_novo_meta_boxes = $_POST[ 'porto-novo-page' ];
            update_post_meta( $post_id, 'porto-novo-page', $porto_novo_meta_boxes );
        }
    }

    add_action( 'save_post', 'porto_novo_save_page_meta_boxes' );

    function porto_novo_conditional_scripts() {

        $menu_type = porto_novo_get_menu_type();

        if ('horizontal-menu-header-1' === $menu_type) {
            wp_enqueue_style( 'horizontal-menu-1', get_template_directory_uri() . '/assets/stylesheets/horizontal-menu-1-style.css' );
        }

        if ('horizontal-menu-header-2' === $menu_type) {
            wp_enqueue_style( 'horizontal-menu-2', get_template_directory_uri() . '/assets/stylesheets/horizontal-menu-2-style.css' );
        }

        if ('horizontal-menu-header-3' === $menu_type) {
            wp_enqueue_style( 'horizontal-menu-3', get_template_directory_uri() . '/assets/stylesheets/horizontal-menu-3-style.css' );
        }

        if ('horizontal-menu-header-4' === $menu_type) {
            wp_enqueue_style( 'horizontal-menu-4', get_template_directory_uri() . '/assets/stylesheets/horizontal-menu-4-style.css' );
        }
    }

    add_action( 'get_footer', 'porto_novo_conditional_scripts' );

    function porto_novo_get_category_template_class() {
        GLOBAL $porto_novo_options;
        $categories_template = porto_novo_get_proper_value( $porto_novo_options, 'opt-blog-template', 'grid-2-left' );
        $sidebar_status = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-sidebar', 1 );

        if (empty( $categories_template )) {
            $categories_template = 'grid-2-left';
        }

        if (!$sidebar_status) {
            $categories_template = '';
        }

        $categories_template = 'porto-novo ' . $categories_template;

        $with_sidebar = "no-sidebar content-area-no-sidebar";
        if (is_active_sidebar( 'sidebar-1' ))
            $with_sidebar = "with-sidebar content-area-plus-sidebar";

        $class = apply_filters( "porto_novo_category_class", "$categories_template $with_sidebar" );

        return $class;
    }

    add_filter( 'wp_ajax_nopriv_porto_novo_get_refreshed_cart_content', 'porto_novo_get_refreshed_cart_content' );
    add_filter( 'wp_ajax_porto_novo_get_refreshed_cart_content', 'porto_novo_get_refreshed_cart_content' );
    function porto_novo_get_refreshed_cart_content()
    {
        porto_novo_get_header_icons();
        die();
    }
    function porto_novo_get_header_icons() {
        global $woocommerce;
        $cart_url = wc_get_cart_url();
        $items_count = WC()->cart->get_cart_contents_count();
        ?>


        <div class="masthead-icon" id="masthead-cart-icon">
            <i class="ti-shopping-cart"></i>

    <?php if ($items_count > 0) : ?>

                <span class="cart-items-count bounce"><?php echo esc_attr( $items_count ); ?></span>

    <?php else : ?>

                <span class="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>

    <?php endif; ?>

            <div class="wc-mini-cart">
                <div class="form-top-arrow"></div>
    <?php woocommerce_mini_cart(); ?>
            </div>

        </div>

        <a href="<?php echo esc_url( $cart_url ); ?>" class="mobile-masthead-icon" id="mobile-masthead-cart-icon">
            <i class="ti-shopping-cart"></i>

            <span class="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>

        </a>
    <?php
    if (function_exists( 'YITH_WCWL' )):
        $porto_novo_wishlist_url = YITH_WCWL()->get_wishlist_url();
        $porto_novo_wishlist_count_products = YITH_WCWL()->count_products();
        ?>
            <div class="masthead-icon" id="masthead-wishlist-icon">
                <a href="<?php echo esc_url( $porto_novo_wishlist_url ) ?>"><i class="ti-heart"></i>
        <?php
        if (0 === $porto_novo_wishlist_count_products) :
            ?>
                        <span id="wishlist-items-count" class=""><?php echo esc_attr( $porto_novo_wishlist_count_products ) ?></span>
                    <?php else : ?>
                        <span id="wishlist-items-count" class="bounce"><?php echo esc_attr( $porto_novo_wishlist_count_products ) ?></span>
                    <?php endif; ?>
                </a>
            </div>
    <?php
    endif;
}

// Return an alternate title, without prefix, for every type used in the get_the_archive_title().
add_filter( 'get_the_archive_title', function ($title) {
    if (is_category()) {
        $title = single_cat_title( '', false );
    } elseif (is_tag()) {
        $title = single_tag_title( '', false );
    } elseif (is_author()) {
        $title = '<span class="vcard">' . get_the_author() . '</span>';
    } elseif (is_year()) {
        $title = get_the_date( _x( 'Y', 'yearly archives date format', 'porto-novo' ) );
    } elseif (is_month()) {
        $title = get_the_date( _x( 'F Y', 'monthly archives date format', 'porto-novo' ) );
    } elseif (is_day()) {
        $title = get_the_date( _x( 'F j, Y', 'daily archives date format', 'porto-novo' ) );
    } elseif (is_tax( 'post_format' )) {
        if (is_tax( 'post_format', 'post-format-aside' )) {
            $title = _x( 'Asides', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-gallery' )) {
            $title = _x( 'Galleries', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-image' )) {
            $title = _x( 'Images', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-video' )) {
            $title = _x( 'Videos', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-quote' )) {
            $title = _x( 'Quotes', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-link' )) {
            $title = _x( 'Links', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-status' )) {
            $title = _x( 'Statuses', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-audio' )) {
            $title = _x( 'Audio', 'post format archive title', 'porto-novo' );
        } elseif (is_tax( 'post_format', 'post-format-chat' )) {
            $title = _x( 'Chats', 'post format archive title', 'porto-novo' );
        }
    } elseif (is_post_type_archive()) {
        $title = post_type_archive_title( '', false );
    } elseif (is_tax()) {
        $title = single_term_title( '', false );
    } else {
        $title = __( 'Archives', 'porto-novo' );
    }
    return $title;
} );

function porto_novo_get_post_content( $post_format, $content ) {
    $output = '';
    switch ($post_format) {
        case 'link':
            $output = str_replace( porto_novo_get_post_format_link(), '', $content );
            break;
        case 'audio':
        case 'video':
            $output = str_replace( porto_novo_get_post_format_raw_url(), '', $content );
            break;
        case 'quote':
            $output = str_replace( porto_novo_get_post_thumb(), '', $content );
            break;
        default:
            $output = $content;
            break;
    }

    return $output;
}

function porto_novo_get_proper_value( $values, $search_key, $default_value = "" ) {
    if (isset( $values[ $search_key ] ))
        $default_value = $values[ $search_key ];
    return $default_value;
}

function porto_novo_remove_add_to_cart_button() {
    GLOBAL $porto_novo_options;
    $add_to_cart_display = porto_novo_get_proper_value( $porto_novo_options, 'opt-add-to-cart-display', '0' );

    if ('0' === $add_to_cart_display) {
        remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart' );
        remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart' );
    }
}

add_action( 'init', 'porto_novo_remove_add_to_cart_button', 100 );

function porto_novo_horizontal_menu_3_icons() {
    global $woocommerce;
    $cart_url = wc_get_cart_url();
    $items_count = WC()->cart->get_cart_contents_count();
    ?>

        <div class="icons-wrap">

            <div class="masthead-icon" id="masthead-user-icon">
                <i class="icon-user"></i>

                <div id="header-login-form-wrap">
                    <div class="form-top-arrow"></div>
    <?php
    $args = array(
        'redirect' => home_url(),
        'form_id' => 'header-login-form',
        'id_username' => 'login-username',
        'id_password' => 'login-password',
    );
    wp_login_form( $args );
    ?>

                </div>
            </div>

            <div class="masthead-icon" id="masthead-cart-icon">
                <i class="icon-basket"></i>

    <?php if ($items_count > 0) : ?>

                    <span id="cart-items-count" class="bounce"><?php echo esc_attr( $items_count ); ?></span>

    <?php else : ?>

                    <span id="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>

    <?php endif; ?>

                <div class="wc-mini-cart">
                    <div class="form-top-arrow"></div>
    <?php woocommerce_mini_cart(); ?>
                </div>
            </div>

            <a href="<?php echo esc_url( $cart_url ); ?>" class="mobile-masthead-icon" id="mobile-masthead-cart-icon">
                <i class="icon-basket"></i>

                <span id="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>
            </a>

            <div class="masthead-icon" id="masthead-search-icon">
                <i class="icon-magnifier"></i>

                <div id="header-search-form-wrap">
                    <div class="form-top-arrow"></div>
    <?php get_search_form(); ?>
                </div>
            </div>

            <span class="masthead-icon" id="top-menu-icon"><i class="ti-align-right"></i></span>

        </div>
    <?php
}

function porto_novo_horizontal_menu_4_icons() {
    global $woocommerce;
    $cart_url = wc_get_cart_url();
    $items_count = WC()->cart->get_cart_contents_count();
    ?>

        <div class="icons-wrap">

            <div class="content-on-left">
                <div class="masthead-icon" id="masthead-search-icon">
                    <i class="icon-magnifier"></i>
                </div>
            </div>

            <div class="content-on-right">
                <div id="extra-menu-wrap">
    <?php wp_nav_menu( array( 'theme_location' => 'extra-menu', 'menu_id' => 'horizontal-extra-menu' ) ); ?>
                </div>

                <div class="masthead-icon" id="masthead-cart-icon">
                    <i class="icon-basket"></i>

    <?php if ($items_count > 0) : ?>

                        <span id="cart-items-count" class="bounce"><?php echo esc_attr( $items_count ); ?></span>

    <?php else : ?>

                        <span id="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>

    <?php endif; ?>

                    <div class="wc-mini-cart">
                        <div class="form-top-arrow"></div>
    <?php woocommerce_mini_cart(); ?>
                    </div>
                </div>

                <a href="<?php echo esc_url( $cart_url ); ?>" class="mobile-masthead-icon" id="mobile-masthead-cart-icon">
                    <i class="icon-basket"></i>

                    <span id="cart-items-count"><?php echo esc_attr( $items_count ); ?></span>
                </a>

                <div class="masthead-icon" id="top-menu-icon"><i class="ti-align-right"></i></div>
            </div>

        </div>
    <?php
}

function porto_novo_horizontal_menu_3_currency() {
    ?>
        <div class="header-currency-wrap">
            <select name="" id="header-currency">
                <option value="USD" selected>USD</option>
                <option value="EUR" selected>EUR</option>
            </select>
        </div>
    <?php
}

function porto_novo_menu_types() {
    global $porto_novo_options;
    $menu_type = porto_novo_get_menu_type();
    $header_class = '';
    $items_count = 0;

    $is_sticky_active = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-sticky', 1 );

    if ($is_sticky_active)
        $header_class = "sticky-enabled";

    if ((isset( $slider_post_ids ) && $slider_post_ids && is_front_page() && 'horizontal-menu-header-2' !== $menu_type) || (is_404() && 'horizontal-menu-header-2' !== $menu_type) || (isset( $revo_slider ) && $revo_slider && is_front_page() && 'horizontal-menu-header-1' === $menu_type))
        $header_class.=" home-slider-enabled";
    ?>

        <div id="header-wrap" class="<?php echo esc_attr( $header_class ); ?>">

            <header id="masthead" class="site-header <?php echo esc_attr( $menu_type ); ?>" >

    <?php porto_novo_get_logo(); ?>

                <span class="masthead-icon" id="top-menu-icon"><i class="ti-align-right"></i></span>

                <div class="header-icons-wrap">
    <?php porto_novo_social_menu(); ?>
    <?php
    if (class_exists( 'WooCommerce' )) {
        if (isset( $porto_novo_options[ 'opt-shop-icons-display' ] ) && "shop" === $porto_novo_options[ 'opt-shop-icons-display' ]) {
            if(WC()->cart){
                $items_count = WC()->cart->get_cart_contents_count();
            }
            if (is_shop() || is_product() || is_cart() || is_checkout() || (function_exists( 'yith_wcwl_is_wishlist_page' ) && yith_wcwl_is_wishlist_page()) || $items_count) {
                porto_novo_get_header_icons();
            }
        } else {
            porto_novo_get_header_icons();
        }
    }
    ?>
                </div>
                    <?php
                    if ("vertical-menu" !== $menu_type) {
                        ?>

                    <nav id="horizontal-site-navigation">

                        <div id="horizontal-menu-wrap">
        <?php wp_nav_menu( array( 'theme_location' => 'top', 'menu_id' => 'horizontal-menu' ) ); ?>
                        </div>

                    </nav>
                            <?php
                        }
                        ?>
            </header>

                <?php get_template_part( 'components/navigation/navigation', 'top' ); ?>

        </div>
            <?php
        }

        function porto_novo_wpd_menu_types() {
            global $porto_novo_options;

            global $porto_novo_page_settings;

            $post_id = get_the_ID();
            $porto_novo_page_settings = get_post_meta( $post_id, "porto-novo-page", true );
            $revo_slider = porto_novo_get_proper_value( $porto_novo_page_settings, "revo-slider", false );
            $slider_post_ids = porto_novo_get_home_slider_posts_id();

            $menu_type = porto_novo_get_menu_type();

            $header_class = '';

            $is_sticky_active = porto_novo_get_proper_value( $porto_novo_options, 'opt-enable-sticky', 1 );

            if ($is_sticky_active)
                $header_class = "sticky-enabled";


            if (
                    ($slider_post_ids && is_front_page() && 'horizontal-menu-header-2' !== $menu_type) || (is_404() && 'horizontal-menu-header-2' !== $menu_type) || ($revo_slider && is_front_page() && 'horizontal-menu-header-1' === $menu_type)
            )
                $header_class.=" home-slider-enabled";
            ?>


        <?php
        if ('horizontal-menu-header-4' === $menu_type) {
            ?>
            <div id="header-wrap" class="<?php echo esc_attr( $header_class ); ?>">

                <div class="header-search-wrap">
                    <div id="header-search-container">
                        <div class="search-close">
                            <i class="ti-close"></i>
                        </div>
            <?php get_search_form(); ?>
                    </div>
                </div>

                <header id="masthead" class="site-header <?php echo esc_attr( $menu_type ); ?>" >
        <?php
        porto_novo_horizontal_menu_4_icons();
        porto_novo_get_logo();
        ?>
                    <nav id="horizontal-site-navigation" class="wpd-horizontal-navigation">

                        <div id="horizontal-menu-wrap">
        <?php wp_nav_menu( array( 'theme_location' => 'top', 'menu_id' => 'horizontal-menu' ) ); ?>
                        </div>

                    </nav>

                </header>

        <?php get_template_part( 'components/navigation/navigation', 'top' ); ?>

            </div>
                            <?php
                        }
                        ?>

    <?php
    if ('horizontal-menu-header-3' === $menu_type) {
        ?>
            <div id="header-wrap" class="<?php echo esc_attr( $header_class ); ?>">

            <?php porto_novo_get_logo(); ?>

                <header id="masthead" class="site-header <?php echo esc_attr( $menu_type ); ?>" >
            <?php
            porto_novo_horizontal_menu_3_currency();
            ?>
                    <nav id="horizontal-site-navigation" class="wpd-horizontal-navigation">

                        <div id="horizontal-menu-wrap">
                <?php wp_nav_menu( array( 'theme_location' => 'top', 'menu_id' => 'horizontal-menu' ) ); ?>
                        </div>

                    </nav>
                    <?php
                    porto_novo_horizontal_menu_3_icons();
                    ?>
                </header>

                            <?php get_template_part( 'components/navigation/navigation', 'top' ); ?>

            </div>

                    <?php
                }
            }

            function porto_novo_get_menu_type() {
                GLOBAL $porto_novo_options;

                $menu_type = porto_novo_get_proper_value( $porto_novo_options, 'opt-menu-type', 'horizontal-menu-header-2' );
                return apply_filters( 'porto_novo_menu_type', $menu_type );
            }

    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );

/* Disable VC auto-update */
function porto_novo_vc_disable_update() {
    if (function_exists('vc_license') && function_exists('vc_updater') && ! vc_license()->isActivated()) {

        remove_filter( 'upgrader_pre_download', array( vc_updater(), 'preUpgradeFilter' ), 10);
        remove_filter( 'pre_set_site_transient_update_plugins', array(
            vc_updater()->updateManager(),
            'check_update'
        ) );

    }
}
add_action( 'admin_init', 'porto_novo_vc_disable_update', 9 );


//prevent wpd plugin to get updates from Envato
function porto_novo_disable_wpd_updates($process){
    return false;
}
add_filter('wpd_include_updater_files', 'porto_novo_disable_wpd_updates');
