<?php

/**
 * ReduxFramework Barebones Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (!class_exists( 'Redux' )) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "porto_novo_options";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */
$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get( 'Name' ),
    // Name that appears at the top of your panel
    'display_version' => $theme->get( 'Version' ),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__( 'Porto-Novo', 'porto-novo' ),
    'page_title' => esc_html__( 'Porto-Novo Options', 'porto-novo' ),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => get_template_directory_uri() . "/assets/images/01_porto-novo-logo_grey.png",
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => 'porto_novo_options',
    // Page slug used to denote the panel
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'footer_credit' => '', // Disable the footer credit of Redux. Please leave if you can help it.
    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
    //'compiler'             => true,
    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'light',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);

Redux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */

/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

// -> START Basic Fields
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'General settings', 'porto-novo' ),
    'id' => 'opt-porto-novo-general',
    'desc' => esc_html__( 'Set general options here', 'porto-novo' ),
    'icon' => 'el el-home',
//    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt-upload-logo-image',
            'type' => 'media',
            'title' => esc_html__( 'Logo', 'porto-novo' ),
            'url' => true,
            'compiler' => 'true',
            'default' => "",
        ),
        array(
            'id' => 'opt-loader-color',
            'type' => 'color',
            'title' => esc_html__( 'Page loader color', 'porto-novo' ),
            'output' => array( 'border-top-color' => '#loader, #loader:before, #loader:after' ),
            'visited' => false
        ),
        array(
            'id' => 'opt-display-breadcrumbs',
            'type' => 'switch',
            'default' => '1', // 1 = on | 0 = off
            'title' => esc_html__( 'Display breadcrumbs', 'porto-novo' ),
            'hint' => array(
                'content' => 'Display or hide breadcrumbs',
            )
        ),
        array(
            'id' => 'opt-enable-sidebar',
            'type' => 'switch',
            'default' => '1', // 1 = on | 0 = off
            'title' => esc_html__( 'Enable sidebar', 'porto-novo' ),
            'hint' => array(
                'content' => esc_html__( 'Display or hide the left sidebad', 'porto-novo' ),
            )
        ),
        array(
            'id' => 'opt-buttons-text-color',
            'type' => 'color',
            'title' => esc_html__( 'Buttons text color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set buttons text color here', 'porto-novo' ),
            'output' => array( 'button:not(.quantity-minus):not(.quantity-plus), input[type="button"], input[type="reset"], input[type="submit"], .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit.disabled, .woocommerce a.button.disabled, .woocommerce button.button.disabled, .woocommerce input.button.disabled, .woocommerce #respond input#submit.alt.disabled, .woocommerce a.button.alt.disabled, .woocommerce button.button.alt.disabled, .woocommerce input.button.alt.disabled, .woocommerce-cart .wc-proceed-to-checkout a.checkout-button, .woocommerce table.shop_table td.actions input[type="submit"], .social-network-links a, #home-slider-area .blog-slider-caption-wrap .blog-slider-read-more a, .horizontal-menu-header-3 .wc-mini-cart p.buttons a, .horizontal-menu-header-4 .wc-mini-cart p.buttons a' ),
        ),
        array(
            'id' => 'opt-buttons-background',
            'type' => 'color',
            'title' => esc_html__( 'Regular buttons background color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set buttons background color here', 'porto-novo' ),
            'output' => array( 'background' => '#page button:not(.quantity-minus):not(.quantity-plus), #page input[type="button"], #page input[type="reset"], #page input[type="submit"], .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit.disabled, .woocommerce a.button.disabled, .woocommerce button.button.disabled, .woocommerce input.button.disabled, .woocommerce #respond input#submit.alt.disabled, .woocommerce a.button.alt.disabled, .woocommerce button.button.alt.disabled, .woocommerce input.button.alt.disabled, #portfolio-single-info-wrap a.button, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li span.current, ul.page-numbers li span.current, .woocommerce-cart .wc-proceed-to-checkout a.checkout-button, .social-network-links a, #home-slider-area .blog-slider-caption-wrap .blog-slider-read-more a, .horizontal-menu-header-3 .wc-mini-cart p.buttons a, .horizontal-menu-header-4 .wc-mini-cart p.buttons a', 'border-color' => '.wc-mini-cart p.buttons a, .woocommerce-cart .wc-proceed-to-checkout a.checkout-button, .woocommerce #payment #place_order, .woocommerce-page #payment #place_order, .after-add-to-cart-button, .woocommerce .woocommerce-error .button, .woocommerce .woocommerce-info .button, .woocommerce .woocommerce-message .button' ),
        ),
        array(
            'id' => 'opt-buttons-text-hover',
            'type' => 'color',
            'title' => esc_html__( 'Buttons text color on hover', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set buttons text color on hover here', 'porto-novo' ),
            'output' => array( '#page button:not(.quantity-minus):not(.quantity-plus):hover, #page input[type="button"]:hover, #page input[type="reset"]:hover, #page input[type="submit"]:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, #portfolio-single-info-wrap a.button:hover, div.archive-product-buttons a:hover, .woocommerce nav.woocommerce-pagination ul li a:hover, ul.page-numbers li a:hover, .wc-mini-cart p.buttons a:hover, .woocommerce #payment #place_order:hover, .woocommerce-page #payment #place_order:hover, nav.single-product-nav span a:hover, .after-add-to-cart-button:hover, .social-network-links a:hover, .woocommerce .woocommerce-error .button:hover, .woocommerce .woocommerce-info .button:hover, .woocommerce .woocommerce-message .button:hover, div.bx-controls-direction a.bx-next:hover, div.bx-controls-direction a.bx-prev:hover, .tagcloud a:hover, #home-slider-area .blog-slider-caption-wrap .blog-slider-read-more a:hover' ),
        ),
        array(
            'id' => 'opt-buttons-background-hover',
            'type' => 'color',
            'title' => esc_html__( 'Buttons background color on hover', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set buttons background color on hover here', 'porto-novo' ),
            'output' => array( 'background' => '#page button:not(.quantity-minus):not(.quantity-plus):hover, #page input[type="button"]:hover, #page input[type="reset"]:hover, #page input[type="submit"]:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, #portfolio-single-info-wrap a.button:hover, div.archive-product-buttons a:hover, .woocommerce nav.woocommerce-pagination ul li a:hover, ul.page-numbers li a:hover, .wc-mini-cart #respond input#submit:hover, .wc-mini-cart a.button:hover, .wc-mini-cart button.button:hover, .wc-mini-cart input.button:hover, .woocommerce #payment #place_order:hover, .woocommerce-page #payment #place_order:hover, nav.single-product-nav span a:hover, .after-add-to-cart-button:hover, .social-network-links a:hover, .woocommerce .woocommerce-error .button:hover, .woocommerce .woocommerce-info .button:hover, .woocommerce .woocommerce-message .button:hover, div.bx-controls-direction a.bx-next:hover, div.bx-controls-direction a.bx-prev:hover, .tagcloud a:hover, #home-slider-area .blog-slider-caption-wrap .blog-slider-read-more a:hover, .horizontal-menu-header-3 .wc-mini-cart p.buttons a:hover, .horizontal-menu-header-4 .wc-mini-cart p.buttons a:hover', 'border-color' => '.wc-mini-cart p.buttons a:hover, .woocommerce #payment #place_order:hover, .woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover, .woocommerce-page #payment #place_order:hover, .after-add-to-cart-button:hover, .woocommerce .woocommerce-error .button:hover, .woocommerce .woocommerce-info .button:hover, .woocommerce .woocommerce-message .button:hover, .tagcloud a:hover' ),
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Coming soon', 'porto-novo' ),
    'id' => 'opt-porto-novo-coming-soon',
    'desc' => esc_html__( 'Set coming soon options here', 'porto-novo' ),
    //'subsection' => true,
    "icon" => 'fa fa-hourglass-half',
    'fields' => array(
        array(
            'id' => 'opt-enable-coming-soon',
            'type' => 'switch',
            'default' => "0", // 1 = on | 0 = off
            'title' => esc_html__( ' Enable coming soon', 'porto-novo' ),
            'hint' => array(
                'content' => esc_html__( 'Enable on disablecoming soon', 'porto-novo' ),
            )
        ),
        array(
            'id' => 'opt-coming-soon-date',
            'type' => 'date',
            'default' => '', // 1 = on | 0 = off
            'title' => esc_html__( ' Launching date', 'porto-novo' ),
        ),
        array(
            'id' => 'opt-coming-soon-msg',
            'type' => 'editor',
            'title' => esc_html__( 'Coming soon', 'porto-novo' ),
            'subtitle' => esc_html__( 'Coming soon message', 'porto-novo' ),
            'default' => '',
        ),
        array(
            'id' => 'opt-coming-soon-background',
            'type' => 'background',
            'title' => esc_html__( 'Coming soon page background', 'porto-novo' ),
            'output' => array( 'body.coming-soon-active' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-coming-soon-text-color',
            'type' => 'color',
            'title' => esc_html__( 'Text color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set text color on the coming soon page', 'porto-novo' ),
            'output' => array( '.coming-soon-header, #timer-container div, .coming-soon-content-area .social-network-container p.title, footer.transparent-footer div.site-info' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-coming-soon-numbers-color',
            'type' => 'color',
            'title' => esc_html__( 'Numbers color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set time text color', 'porto-novo' ),
            'output' => array( '#timer-container div .number' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-coming-soon-time-background',
            'type' => 'color_rgba',
            'title' => esc_html__( 'Time containers background color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set time containers background color', 'porto-novo' ),
            'output' => array( 'background' => '#timer-container div .number' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-coming-soon-time-border-color',
            'type' => 'color',
            'title' => esc_html__( 'Time containers border color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set time containers border color', 'porto-novo' ),
            'output' => array( 'border-color' => '#timer-container div .number' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-coming-soon-time-border-width',
            'type' => 'spinner',
            'title' => esc_html__( 'Time containers border width', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set time containers border width in pixels', 'porto-novo' ),
            'output' => array( 'border-width' => '#timer-container div .number' ),
            'min' => '0',
            'max' => '10',
            'default' => '3',
        ),
        array(
            'id' => 'opt-coming-soon-time-border-radius',
            'type' => 'spinner',
            'title' => esc_html__( 'Time containers border radius', 'porto-novo' ),
            'subtitle' => esc_html__( 'Setting this option will allow you to control the containers shape. Going from square to perfect circle', 'porto-novo' ),
            'output' => array( 'border-radius' => '#timer-container div .number' ),
            'min' => '0',
            'max' => '70',
            'default' => '70',
        ),
        array(
            'id' => 'opt-coming-soon-padding-ajustment',
            'type' => 'spinner',
            'title' => esc_html__( 'Coming soon padding ajustment', 'porto-novo' ),
            'subtitle' => esc_html__( 'Setting this option will allow you to control the gap between the header and the time left. You can then verticaly ajust the time position.', 'porto-novo' ),
            'output' => array( 'padding-bottom' => '.coming-soon-header' ),
            'min' => '50',
            'max' => '200',
            'default' => '100',
        ),
        array(
            'id' => 'opt-display-coming-soon-social-links',
            'type' => 'switch',
            'default' => '0', // 1 = on | 0 = off
            'title' => esc_html__( 'Display social links', 'porto-novo' ),
            'subtitle' => esc_html__( 'Show/hide social links on the coming soon page', 'porto-novo' ),
        )
    ),
) );



/**
 * Titles typography
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Styles & Typography', 'porto-novo' ),
    'id' => 'h1-section',
    'desc' => esc_html__( 'Set heading & body options here', 'porto-novo' ),
    //'subsection' => true,
    "icon" => "el el-text-width",
    'fields' => array(
        array(
            'id' => 'opt-h1-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h1, header.page-header h1.page-title' ),
            'title' => esc_html__( 'H1 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-h2-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h2' ),
            'title' => esc_html__( 'H2 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-h3-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h3' ),
            'title' => esc_html__( 'H3 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-h4-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h4' ),
            'title' => esc_html__( 'H4 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-h5-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h5' ),
            'title' => esc_html__( 'H5 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-h6-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'h6' ),
            'title' => esc_html__( 'H6 typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-body-background',
            'type' => 'background',
            'title' => esc_html__( 'Body background', 'porto-novo' ),
            'output' => array( 'body' ),
            'default' => array(),
        ),
        array(
            'id' => 'opt-body-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'body' ),
            'title' => esc_html__( 'Body typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'default' => array(),
        ),
    )
) );

/**
 * Sticky Header
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Header & Menus', 'porto-novo' ),
    'id' => 'top-header-section',
    'desc' => esc_html__( 'Set header options here', 'porto-novo' ),
    // 'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt-enable-sticky',
            'type' => 'switch',
            'default' => '1', // 1 = on | 0 = off
            'title' => esc_html__( 'Enable sticky menu', 'porto-novo' ),
            'hint' => array(
                'content' => 'Whether or not to disable the sticky menu behavior',
            )
        ),
        array(
            'id' => 'opt-menu-position',
            'type' => 'select',
            'title' => esc_html__( 'Top header position', 'porto-novo' ),
            'options' => array(
                'above-all' => 'Above all pages',
                'over-all' => 'Over all pages',
                'over-frontpage' => 'Over frontpage only'
            ),
            'default' => 'above-all'
        ),
        array(
            'id' => 'opt-header-wrap-background',
            'type' => 'color',
            'title' => esc_html__( 'Top header background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set top header background color here', 'porto-novo' ),
            'output' => array( 'background-color' => '#header-wrap:not(.home-slider-enabled), #header-wrap.header-sticky, header.horizontal-menu-header-4.header-sticky, header.horizontal-menu-header-3.header-sticky' )
        ),
        array(
            'id' => 'opt-menu-type',
            'type' => 'select',
            'title' => esc_html__( 'Navigation Type', 'porto-novo' ),
            'options' => array(
                'horizontal-menu-header-1' => 'Horizontal 1',
                'horizontal-menu-header-2' => 'Horizontal 2',
                'horizontal-menu-header-3' => 'Horizontal 3',
                'horizontal-menu-header-4' => 'Horizontal 4',
                'vertical-menu' => 'Vertical',
            ),
            'default' => 'horizontal-menu-header-1'
        ),
        array(
            'id' => 'opt-top-main-menu-color',
            'type' => 'link_color',
            'title' => esc_html__( 'Main navigation menu color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set main menus colors here', 'porto-novo' ),
            'output' => array( '#site-navigation ul#top-menu > li > a, #site-navigation, header.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu > li > a, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu > li > a, header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu > li > a, header.horizontal-menu-header-4 nav#horizontal-site-navigation ul#horizontal-menu > li > a, div.content-on-right #horizontal-extra-menu li a, .content-on-left #masthead-search-icon, .content-on-right #masthead-cart-icon, header .icons-wrap .masthead-icon, .header-currency-wrap select#header-currency, header #mobile-masthead-cart-icon' ),
            'visited' => false,
            'default' => array()
        ),
        array(
            'id' => 'opt-top-sub-menu-color',
            'type' => 'link_color',
            'title' => esc_html__( 'Navigation sub-menu color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set sub-menus colors here', 'porto-novo' ),
            'output' => array( 'header.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu li a, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu li a, header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu li a, header.horizontal-menu-header-4 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu li a' ),
            'visited' => false,
            'default' => array()
        ),
        array(
            'id' => 'opt-top-header-current-menu-color',
            'type' => 'color',
            'title' => esc_html__( 'Current menu color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set menu color when accessing the page', 'porto-novo' ),
            'output' => array( 'background-color' => '.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu > li.current_page_item >  a:before', 'color' => '.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu > li.current_page_item > a, .horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu > li.current_page_item > a, #site-navigation ul#top-menu li.current-menu-item > a, .horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu > li.current_page_item > a, .horizontal-menu-header-4 nav#horizontal-site-navigation ul#horizontal-menu > li.current_page_item > a, div.content-on-right #horizontal-extra-menu > li.current_page_item > a, #site-navigation ul#top-menu li.current-menu-item > a' ),
            'visited' => false,
        ),
        array(
            'id' => 'opt-top-header-menu-background',
            'type' => 'color',
            'title' => esc_html__( 'Navigation menu background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set menus background color on hover', 'porto-novo' ),
            'output' => array( 'background-color' => 'header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu > li > a:before , header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu a:hover, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu li.megamenu > ul > li > a' ),
            'required' => array( 'opt-menu-type', 'equals', 'horizontal-menu-header-2' ),
            'visited' => false,
        ),
        array(
            'id' => 'opt-top-header-menu-bg',
            'type' => 'background',
            'title' => esc_html__( 'Navigation submenu background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set background color of menus dropdown list here', 'porto-novo' ),
            'output' => array( 'header.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu ul, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu ul, header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu ul, header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu > li > ul.sub-menu:before, header.horizontal-menu-header-4 nav#horizontal-site-navigation ul#horizontal-menu ul, #site-navigation' ),
            'required' => array( 'opt-menu-type', 'equals', array( 'horizontal-menu-header-1', 'horizontal-menu-header-2', 'horizontal-menu-header-3' ) ),
            'visited' => false,
            'default' => array()
        ),
        array(
            'id' => 'opt-top-header-4-menu-bg',
            'type' => 'color_rgba',
            'title' => esc_html__( 'Navigation submenu background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set background color of menus dropdown list here', 'porto-novo' ),
            'output' => array( 'header.horizontal-menu-header-4 nav#horizontal-site-navigation ul#horizontal-menu ul' ),
            'required' => array( 'opt-menu-type', 'equals', array( 'horizontal-menu-header-4' ) ),
            'visited' => false,
            'default' => array()
        ),
        array(
            'id' => 'opt-top-header-search-container-background',
            'type' => 'color_rgba',
            'title' => esc_html__( 'Search field container background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set search field container background color here', 'porto-novo' ),
            'output' => array( 'background-color' => 'div#header-wrap .header-search-wrap' ),
            'required' => array( 'opt-menu-type', 'equals', 'horizontal-menu-header-4' ),
            'visited' => false,
        ),
        array(
            'id' => 'opt-top-header-search-border-color',
            'type' => 'color',
            'title' => esc_html__( 'Search field border color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set search field border color here', 'porto-novo' ),
            'output' => array( 'border-color' => 'div#header-wrap .header-search-wrap #header-search-container .searchform input', 'color' => 'div#header-wrap .header-search-wrap #header-search-container .search-close, div#header-wrap .header-search-wrap #header-search-container .searchform input' ),
            'required' => array( 'opt-menu-type', 'equals', 'horizontal-menu-header-4' ),
            'visited' => false,
        ),
        array(
            'id' => 'opt-top-header-submenu-border-color',
            'type' => 'color',
            'title' => esc_html__( 'Submenu border color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set submenus border color here', 'porto-novo' ),
            'output' => array( 'border-color' => 'header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu ul.sub-menu, header.horizontal-menu-header-3 nav#horizontal-site-navigation ul#horizontal-menu > li > ul.sub-menu:before' ),
            'required' => array( 'opt-menu-type', 'equals', 'horizontal-menu-header-3' ),
            'visited' => false,
        ),
        array(
            'id' => 'opt-top-header-background',
            'type' => 'background',
            'title' => esc_html__( 'Navigation background', 'porto-novo' ),
            'output' => array( '#site-navigation' ),
            'required' => array( 'opt-menu-type', 'equals', 'vertical-menu' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-top-header-menu-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( '#site-navigation ul#top-menu li a, header.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu li a, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu li a, header.horizontal-menu-header-1 nav#horizontal-site-navigation ul#horizontal-menu ul li a, header.horizontal-menu-header-2 nav#horizontal-site-navigation ul#horizontal-menu ul li a' ),
            'title' => esc_html__( 'Top header menu typography', 'porto-novo' ),
            'text-align' => false,
            'line-height' => false,
            'color' => false,
            'default' => array(),
        ),
        array(
            'id' => 'opt-page-header-title-color',
            'type' => 'color',
            'title' => esc_html__( 'Page header title color', 'porto-novo' ),
            'output' => array( 'header.page-header h1.page-title' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-breadcrumbs-color',
            'type' => 'color',
            'title' => esc_html__( 'breadcrumbs color', 'porto-novo' ),
            'output' => array( 'header.page-header ul#breadcrumbs, header.page-header ul#breadcrumbs a, header.page-header ul#breadcrumbs .bread-current' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-content-header-background',
            'type' => 'background',
            'title' => esc_html__( 'Page header background', 'porto-novo' ),
            'output' => array( 'header.page-header' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-page-header-height',
            'type' => 'spinner',
            'title' => esc_html__( 'Page header height', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set here page headers height in pixels', 'porto-novo' ),
            'output' => array( 'height' => 'header.page-header' ),
            'default' => "300",
            'min' => '100',
            'max' => '400'
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Home page slider', 'porto-novo' ),
    'id' => 'home-slider-section',
    "icon" => 'fa fa-image',
    'desc' => esc_html__( 'Set Home page slider options here', 'porto-novo' ),
    // 'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt-home-page-slider-type',
            'type' => 'select',
            'title' => esc_html__( 'Slider type', 'porto-novo' ),
            'options' => array(
                'home-basic-slider' => 'Basic',
                'home-blog-slider' => 'Blog',
            ),
            'default' => 'home-basic-slider'
        ),
        array(
            'id' => 'opt-blog-slider-width',
            'type' => 'switch',
            'default' => '0', // 1 = on | 0 = off
            'title' => esc_html__( 'Boxed', 'porto-novo' ),
            'subtitle' => 'This will set the slider width to max 1170px',
            'required' => array( 'opt-home-page-slider-type', 'equals', 'home-blog-slider' ),
        ),
        array(
            'id' => 'opt-home-page-slider-posts',
            'type' => 'select',
            'multi' => true,
            'title' => esc_html__( 'Featured Posts', 'porto-novo' ),
            'subtitle' => esc_html__( 'Selected posts will be displayed in home page slider', 'porto-novo' ),
            'default' => array(),
            'data' => 'posts',
            'args' => array( 'post_type' => array( 'post', 'o-portfolio' ), 'numberposts' => -1 ),
        ),
    )
) );

/**
 * Footer options
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Footer', 'porto-novo' ),
    'id' => 'opt-footer',
    'desc' => esc_html__( 'Set footer options here', 'porto-novo' ),
    'icon' => 'fa fa-pencil-square-o',
    'fields' => array(
        array(
            'id' => 'opt-enable-top-footer',
            'type' => 'switch',
            'default' => '0', // 1 = on | 0 = off
            'title' => esc_html__( 'Enable top footer', 'porto-novo' ),
            'subtitle' => esc_html__( 'Display or hide top footer section', 'porto-novo' ),
        ),
        array(
            'id' => 'opt-top-footer-columns',
            'type' => 'select',
            'title' => esc_html__( 'Top footer columns', 'porto-novo' ),
            'options' => array(
                '1' => '1 column',
                '2' => '2 columns',
                '3' => '3 columns',
                '4' => '4 columns',
                '5' => '5 columns'
            ),
            'default' => '3',
            'required' => array( 'opt-enable-top-footer', 'equals', '1' ),
        ),
        array(
            'id' => 'opt-top-footer-layout',
            'type' => 'select',
            'title' => esc_html__( 'Top footer layout', 'porto-novo' ),
            'options' => array(
                'boxed' => 'Boxed',
                'full-width' => 'Full width',
            ),
            'default' => 'boxed',
            'required' => array( 'opt-enable-top-footer', 'equals', '1' ),
        ),
        array(
            'id' => 'opt-top-footer-max-width',
            'type' => 'text',
            'title' => esc_html__( 'Top footer max width', 'porto-novo' ),
            'subtitle' => esc_html__( 'Enter Top footer max width in pixels', 'porto-novo' ),
            'default' => '1170',
            'validate' => 'numeric',
            'required' => array( 'opt-top-footer-layout', 'equals', 'boxed' ),
        ),
        array(
            'id' => 'opt-footer-background',
            'type' => 'background',
            'title' => esc_html__( 'Footer background', 'porto-novo' ),
            'output' => array( '.site-footer' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-footer-social-link-color',
            'type' => 'link_color',
            'title' => esc_html__( 'Footer social links color', 'porto-novo' ),
            'visited' => false,
            'active' => false,
            'output' => array( 'footer ul#footer-social-links li a' ),
            'default' => array()
        ),
        array(
            'id' => 'opt-footer-social-link-typography',
            'type' => 'typography',
            'google' => false,
            'output' => array( 'footer ul#footer-social-links li a, footer ul#footer-social-links li:before' ),
            'title' => esc_html__( 'Footer social links font size', 'porto-novo' ),
            'text-align' => false,
            'line-height' => false,
            'font-family' => false,
            'font-style' => false,
            'font-weight' => false,
            'color' => false,
            'default' => ""
        ),
        array(
            'id' => 'opt-footer-copyright-section-background',
            'type' => 'background',
            'title' => esc_html__( 'Site info background', 'porto-novo' ),
            'visited' => false,
            'active' => false,
            'output' => array( 'footer div.site-info' ),
            'default' => ""
        ),
        array(
            'id' => 'opt-footer-copyright-section-typo',
            'type' => 'typography',
            'google' => true,
            'output' => array( 'footer div.site-info' ),
            'title' => esc_html__( 'Site info  typography', 'porto-novo' ),
            'text-align' => false,
            'letter-spacing' => true,
            'text-transform' => true,
            'default' => array(),
        ),
        array(
            'id' => 'opt-footer-copyright-msg',
            'type' => 'editor',
            'title' => esc_html__( 'Site info content', 'porto-novo' ),
//	    'subtitle' =>esc_html__( 'Site info section text' ),
            'default' => '',
        ),
    )
        )
);

/**
 * Social info
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Social info', 'porto-novo' ),
    'desc' => esc_html__( 'Set the social info here ', 'porto-novo' ),
    'id' => 'opt-social-info',
    "icon" => "fa fa-facebook-official",
    'compiler' => 'true',
    // 'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt-social-enable',
            'type' => 'switch',
            'title' => esc_html__( 'Enable footer social links', 'porto-novo' ),
            'default' => "1",
        ),
        array(
            'id' => 'opt-social-facebook',
            'type' => 'text',
            'title' => esc_html__( 'Facebook URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-twitter',
            'type' => 'text',
            'title' => esc_html__( 'Twitter URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-pinterest',
            'type' => 'text',
            'title' => esc_html__( 'Pinterest URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-behance',
            'type' => 'text',
            'title' => esc_html__( 'Behance URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-dribbble',
            'type' => 'text',
            'title' => esc_html__( 'Dribbble URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-vimeo',
            'type' => 'text',
            'title' => esc_html__( 'Vimeo URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-tumblr',
            'type' => 'text',
            'title' => esc_html__( 'Tumblr URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-linkedIn',
            'type' => 'text',
            'title' => esc_html__( 'LinkedIn URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-google-plus',
            'type' => 'text',
            'title' => esc_html__( 'Google+ URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-flickr',
            'type' => 'text',
            'title' => esc_html__( 'Flickr URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-youtube',
            'type' => 'text',
            'title' => esc_html__( 'Youtube URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-foursquare',
            'type' => 'text',
            'title' => esc_html__( 'Foursquare URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-instagram',
            'type' => 'text',
            'title' => esc_html__( 'Instagram URL', 'porto-novo' ),
            'default' => "",
        ),
        array(
            'id' => 'opt-social-github',
            'type' => 'text',
            'title' => esc_html__( 'GitHub URL', 'porto-novo' ),
            'default' => "",
        ),
    )
        )
);



Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Blog', 'porto-novo' ),
    'id' => 'blog-section',
    'icon' => 'fa fa-bold',
    'desc' => esc_html__( 'Blog options here', 'porto-novo' ),
    'fields' => array(
        array(
            'id' => 'opt-blog-template',
            'type' => 'select',
            'multi' => false,
            'title' => esc_html__( 'Blog layouts', 'porto-novo' ),
            'subtitle' => esc_html__( 'Blog categories templates', 'porto-novo' ),
            'default' => 'grid-2-left',
            'options' => array(
                "grid-2-left" => esc_html__( "Grid 2columns: Left Sidebar", "porto-novo" ),
                "grid-2-right" => esc_html__( "Grid 2columns: Right Sidebar", "porto-novo" ),
                "list-1-right" => esc_html__( "List 1column: Right Sidebar", "porto-novo" ),
                "list-2-right" => esc_html__( "List 2columns: Right Sidebar", "porto-novo" ),
                "list-1-left" => esc_html__( "List 1column: Left Sidebar", "porto-novo" ),
                "list-2-left" => esc_html__( "List 2columns: Left Sidebar", "porto-novo" ),
            ),
        ),
        array(
            'id' => 'opt-post-title-color',
            'type' => 'color',
            'title' => esc_html__( 'Post title color', 'porto-novo' ),
            'output' => array( 'article.blog-archive-post h2 a, div.search-post-content h2 a' ),
            'visited' => false,
            'default' => '#181818'
        ),
        array(
            'id' => 'opt-post-author-color',
            'type' => 'color',
            'title' => esc_html__( 'Post author color', 'porto-novo' ),
            'output' => array( '.blog-archive-post-extra div:first-child, #blog-single-extra div:nth-child(2) p' ),
            'visited' => false
        ),
        array(
            'id' => 'opt-post-categories-color',
            'type' => 'color',
            'title' => esc_html__( 'Post categories color', 'porto-novo' ),
            'output' => array( 'div.blog-archive-post-extra div:nth-child(2) a, #blog-single-extra div:last-child a' ),
            'visited' => false
        ),
        array(
            'id' => 'opt-widget-title-style',
            'type' => 'select',
            'title' => esc_html__( 'Widget title style', 'porto-novo' ),
            'options' => array(
                'default' => 'default',
            ),
            'default' => 'default'
        ),
        array(
            'id' => 'opt-custom-archive-pages-title',
            'type' => 'editor',
            'title' => esc_html__( 'Custom Archive Pages titles', 'porto-novo' ),
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Shop', 'porto-novo' ),
    'id' => 'opt-shop',
    'desc' => esc_html__( 'Set shop options here', 'porto-novo' ),
    "icon" => 'fa fa-shopping-bag',
    'fields' => array(
        array(
            'id' => 'opt-shop-icons-display',
            'type' => 'select',
            'title' => esc_html__( 'Header shop icons display', 'porto-novo' ),
            'subtitle' => esc_html__( 'Show shop icons either on the whole website or just on shop pages only', 'porto-novo' ),
            'options' => array(
                "everywhere" => esc_html__( "Everywhere", "porto-novo" ),
                "shop" => esc_html__( "Shop pages only", "porto-novo" ),
            ),
            'default' => 'shop',
        ),
        array(
            'id' => 'opt-add-to-cart-display',
            'type' => 'switch',
            'default' => '0', // 1 = on | 0 = off
            'title' => esc_html__( 'Display add to cart button on shop page', 'porto-novo' ),
            'subtitle' => esc_html__( 'Display or hide add to cart button', 'porto-novo' ),
        ),
        array(
            'id' => 'opt-shop-icons-color',
            'type' => 'color',
            'title' => esc_html__( 'Shop icons color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set shop icons color here', 'porto-novo' ),
            'output' => array( 'header .ti-shopping-cart:before, header .ti-heart:before' ),
        ),
        array(
            'id' => 'opt-product-count-background',
            'type' => 'color',
            'title' => esc_html__( 'Shop icons product count background', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set color of the product count background here', 'porto-novo' ),
            'output' => array( 'background-color' => 'header #masthead-cart-icon .cart-items-count, 
			header #masthead-wishlist-icon #wishlist-items-count, 
			header #mobile-masthead-cart-icon .cart-items-count' ),
        ),
        array(
            'id' => 'opt-shop-icons-text-color',
            'type' => 'color',
            'title' => esc_html__( 'Shop icons text color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set product count color here', 'porto-novo' ),
            'output' => array( 'header #masthead-cart-icon .cart-items-count, 
			header #masthead-wishlist-icon #wishlist-items-count, 
			header #mobile-masthead-cart-icon .cart-items-count' ),
        ),
        array(
            'id' => 'opt-product-price-color',
            'type' => 'color',
            'title' => esc_html__( 'Product price and availability color', 'porto-novo' ),
            'subtitle' => esc_html__( 'Set product price and availability color here', 'porto-novo' ),
            'output' => array( '.woocommerce ul.products li.product .price .amount, 
			.woocommerce div.product p.price, .woocommerce div.product span.price,
			.availability-wrap span span, ul.cart_list li span.quantity span.amount, ul.product_list_widget li span.quantity span.amount, .woocommerce table.shop_table td.product-price' ),
        ),
    )
) );


/**
 * WPD
 */
if (function_exists( 'is_plugin_active' ) && is_plugin_active( 'woocommerce-product-designer/wpd.php' )) {
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Product Designer', 'porto-novo' ),
        'id' => 'opt-wpd',
        'desc' => esc_html__( 'Set WooCommerce Product Designer options here', 'porto-novo' ),
        'icon' => 'fa fa-shopping-bag',
        'fields' => array(
            array(
                'id' => 'opt-wpd-special-customization-page',
                'type' => 'switch',
                'default' => '1', // 1 = on | 0 = off
                'title' => esc_html__( 'Apply custom styles to customization page', 'porto-novo' ),
            ),
        )
    ) );
}


/**
 * Portfolio
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Portfolio', 'porto-novo' ),
    'desc' => esc_html__( 'Portfolio layouts here', 'porto-novo' ),
    'id' => 'opt-portfolio-blog-layout',
    "icon" => 'fa fa-briefcase',
    'compiler' => 'true',
    // 'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt-portfolio-blog-layout',
            'type' => 'select',
            'title' => esc_html__( 'Number of columns', 'porto-novo' ),
            'options' => array(
                '2' => '2 column',
                '3' => '3 column'
            ),
            'default' => '3'
        ),
    )
) );

/**
 * Advanced options: custom css and js
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Advanced', 'porto-novo' ),
    'id' => 'opt-advanced',
    'desc' => esc_html__( 'Set additional code js and css here', 'porto-novo' ),
    'icon' => 'fa fa-warning'
) );

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Custom JS', 'porto-novo' ),
    'desc' => esc_html__( 'Set custom js here ', 'porto-novo' ),
    'id' => 'opt-custom-js',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'opt_js_editor',
            'type' => 'ace_editor',
            'title' => esc_html__( 'JS Code', 'porto-novo' ),
            'subtitle' => esc_html__( 'Paste your JS code here.', 'porto-novo' ),
            'mode' => 'javascript',
            'theme' => 'monokai',
            'default' => ""
        ),
    )
) );

/**
 * Demos data section
 */
$memory_limit = ini_get( 'memory_limit' );
$max_execution_time = ini_get( 'max_execution_time' );
global $wpdb;
$max_allowed_packet = $wpdb->get_row( "SHOW VARIABLES LIKE 'max_allowed_packet'" );
$min_required_packet_size = 16777216; //16MB
$error = "";
$content = '

        <div class="redux-demo-block">							
            <a class="orion-install-demo-button" data-demo-id="shop_04" style="margin-top: 30px;">
            <div class="demo-loading">
                    <img src="' . get_template_directory_uri() . '/assets/images/demo-loader.gif"/>
                    </div>
            <img class="preview" src="' . get_template_directory_uri() . '/assets/images/shop-4-image.jpg"/>
            <p>Web to print <font color="red">~ 50MB</font></p>
            </a>

        </div>';

if (preg_match( '/^(\d+)(.)$/', $memory_limit, $matches )) {
    if ($matches[ 2 ] == 'M' && $matches[ 1 ] < 256) {
        $error.='<li>'.__('Please make sure your memory limit is set to at least 256M on the server before being able to import the demos. Current value: ', 'porto-novo') . $memory_limit . '.</li>';
    }
}

if ($max_execution_time < 120) {
    $error.='<li>'.__('Please make sure your max execution time is set to at least 120 on the server before being able to import the demos. Current value: ', 'porto-novo') . $max_execution_time . '.</li>';
}

//if (intval( $max_allowed_packet->Value ) < $min_required_packet_size) {
//    $error.='<li>'.__('Please make sure your mysql max_allowed_packet variable is set to at least 16M on the server before being able to import the demos. Current value: ', 'porto-novo') . $max_allowed_packet->Value . '.</li>';
//}

//if ($error)
//    $content = '<div class="redux-demo-block"><div style="color: red;">' . $error . ' <br><strong>Note: </strong>If you are not sure how to get it done, please ask your hosting company.</div>
//        </div>';

Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Demonstration Data', 'porto-novo' ),
    'desc' => esc_html__( 'Demos data import tool', 'porto-novo' ),
    'id' => 'opt-demo-import',
//    "icon"=>"fa fa-facebook-official",
    'compiler' => 'true',
    // 'subsection' => true,
    'fields' => array(
        array(
            'id' => 'default-demo',
            'type' => 'raw',
            'title' => __( 'Default', 'porto-novo' ),
            'subtitle' => __( 'Click on the button below to import the desired demo data and settings.', 'porto-novo' ),
            'content' =>
            $content
        )
    )
        )
);

/**
 * Purchase code section
 */
Redux::setSection( $opt_name, array(
    'title' => esc_html__( 'Purchase code', 'porto-novo' ),
    'id' => 'opt-porto-novo-purchase-code',
    'desc' => esc_html__( 'Set the theme purchase code here', 'porto-novo' ),
    //'subsection' => true,
    "icon" => 'fa fa-hourglass-half',
    'fields' => array(
        array(
            'id' => 'opt-purchase-code',
            'type' => 'text',
            'default' => '', // 1 = on | 0 = off
            'title' => esc_html__( ' Purchase code', 'porto-novo' ),
        ),
    ),
) );

/*
     * <--- END SECTIONS
     */
