<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.orionorigin.com
 * @since      1.0.0
 *
 * @package    Uie
 * @subpackage Uie/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Uie
 * @subpackage Uie/admin
 * @author     ORION <support@orionorigin.com>
 */
class Uie_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Uie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Uie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/uie-admin.css', array(), $this->version, 'all' );
                wp_enqueue_style("o-ui", plugin_dir_url(__FILE__) . 'css/UI.css', array(), $this->version, 'all');
                wp_enqueue_style("o-colorpicker", plugin_dir_url(__FILE__) . 'js/colorpicker/css/colorpicker.css', array(), $this->version, 'all');
                wp_enqueue_style("select2-css", plugin_dir_url(__FILE__) . 'css/select2.min.css', array(), $this->version, 'all');

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Uie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Uie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/uie-admin.js', array( 'jquery' ), $this->version, false );
                wp_enqueue_script('select2-js', plugin_dir_url(__FILE__) . 'js/select2.min.js', array(), $this->version, 'all');
                wp_enqueue_script("o-admin", plugin_dir_url(__FILE__) . 'js/o-admin.js', array('jquery'), $this->version, false);
                wp_localize_script("o-admin", 'home_url', o_get_medias_root_url("/"));
                wp_enqueue_style("o-flexgrid", plugin_dir_url(__FILE__) . 'css/flexiblegs.css', array(), $this->version, 'all');
                wp_enqueue_script("o-colorpicker", plugin_dir_url(__FILE__) . 'js/colorpicker/js/colorpicker.js', array('jquery'), $this->version, false);

	}
        
        function init_globals()
        {
            global $uie_skins;
            $uie_skins=  uie_get_available_skins();
        }
        
        public function add_uie_menu() {
            $parent_slug = "edit.php?post_type=o-banner";
            add_submenu_page($parent_slug, __('Banners Groups', 'uie'), __('Banners Groups', 'uie'), 'manage_options', 'edit.php?post_type=o-banner-group', false);
//            add_submenu_page($parent_slug, __('Settings', 'wad'), __('Settings', 'wad'), 'manage_options', 'wad-manage-settings', array($this, 'get_wad_settings_page'));
    //        add_submenu_page($parent_slug, __('Get Started', 'wad'), __('Get Started', 'wad'), 'manage_options', 'wad-about', array($this, "get_about_page"));
        }
        
        public function get_max_input_vars_php_ini() {
            $total_max_normal = ini_get('max_input_vars');
            $msg = __("Your max input var is <strong>$total_max_normal</strong> but this page contains <strong>{nb}</strong> fields. You may experience a lost of data after saving. In order to fix this issue, please increase <strong>the max_input_vars</strong> value in your php.ini file.", "vpc");
            ?> 
            <script type="text/javascript">
                var o_max_input_vars = <?php echo $total_max_normal; ?>;
                var o_max_input_msg = "<?php echo $msg; ?>";
            </script>         
            <?php
    }

}
