<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.orionorigin.com
 * @since      1.0.0
 *
 * @package    Uie
 * @subpackage Uie/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Uie
 * @subpackage Uie/public
 * @author     ORION <support@orionorigin.com>
 */
class Uie_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Uie_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Uie_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name, UIE_URL . 'public/css/uie-public.css', array(), $this->version, 'all');
        wp_enqueue_style("o-flexgrid", UIE_URL . 'admin/css/flexiblegs.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Uie_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Uie_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/uie-public.js', array('jquery'), $this->version, false);
    }

    public function uie_register_shortcodes() {
        add_shortcode("uie-banner", array($this, "get_uie_banner"));
        add_shortcode("uie-banner-group", array($this, "get_uie_banner_group"));
    }

    public function get_uie_banner($atts) {
//        global $uie_page_banners;
        ob_start();
        $banner_id = $atts["id"];
        $banner_properties = get_post_meta($banner_id, "o-banner", true);

        if (!$banner_id)
            return __("Wrong shortcode: missing banner ID.", "uie");
        else if (empty($banner_properties))
            return __("No parameter found in the provided ID. Are you sure this is a valid banner ID?", "uie");

        $skin_class = get_proper_value($banner_properties, "style");
        $skin_obj = new $skin_class(false);
        $skin_properties = $skin_obj->get_properties();

//        $uie_page_banners[$banner_id] = array("banner_properties" => $banner_properties, "skin_properties" => $skin_properties);

        $content_html = uie_get_banner_content($banner_id, $banner_properties, $skin_properties);
        echo $content_html;

        return ob_get_clean();
    }

    public function get_uie_banner_group($atts) {
        extract(shortcode_atts(array(
            'id' => '',
                        ), $atts, 'uie-banner-group'));

        $grid_settings = get_post_meta($id, "o-banner-group", true);

        if (!$id)
            return __("Wrong shortcode: missing group ID.", "uie");
        else if (empty($grid_settings))
            return __("No parameter found in the provided ID. Are you sure this is a valid group ID?", "uie");
        ob_start();




        $nm_class = "xl-1-" . $grid_settings["nb-cols-xl"];
//            $lg_class = "lg-1-" . $grid_settings["nb-cols-lg"];
        $md_class = "md-1-" . $grid_settings["nb-cols-md"];
        $sm_class = "sm-1-" . $grid_settings["nb-cols-sm"];
//            $xs_class = "xs-1-" . $grid_settings["nb-cols-xs"];

        $nm_spacing_class = "xl-gutter-" . $grid_settings["xl-spacing"];
//            $lg_spacing_class = "lg-gutter-" . $grid_settings["lg-spacing"];
        $md_spacing_class = "md-gutter-" . $grid_settings["md-spacing"];
        $sm_spacing_class = "sm-gutter-" . $grid_settings["sm-spacing"];
//            $xs_spacing_class = "xs-gutter-" . $grid_settings["xs-spacing"];

        $spacing_class = "$nm_spacing_class $md_spacing_class $sm_spacing_class";
        $grid_classes = "o-col $nm_class $md_class $sm_class";

        $banners = get_proper_value($grid_settings, "banners", array());
        ?>
        <div class='o-wrap <?php echo $spacing_class; ?> uie-main-container'>
        <?php
        foreach ($banners as $banner) {
            $banner_id = get_proper_value($banner, "banner", FALSE);
            if ($banner_id) {
                echo '<div class="' . $grid_classes . '">';
                echo $this->get_uie_banner(array("id" => $banner_id));
                echo '</div>';
            }
        }
        ?>
        </div>
        <?php

        $output = ob_get_contents();
        ob_end_clean();
        return $output;
    }

    function get_banner_shortcodes() {
        global $post;
        $banners_pattern = "\[(\[?)(uie\-banner)(?![\w-])([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";
        $groups_pattern = "\[(\[?)(uie\-banner\-group)(?![\w-])([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";

        if (preg_match_all('/' . $banners_pattern . '/s', $post->post_content, $matches)
        ) {
            $raw_parameters = $matches[3];

            foreach ($raw_parameters as $raw_parameter) {
                preg_match_all('!\d+!', $raw_parameter, $int_matches);
                $banner_id = $int_matches[0][0];
                $this->get_banner_style($banner_id);
            }
        }

        if (preg_match_all('/' . $groups_pattern . '/s', $post->post_content, $matches)
        ) {
            $raw_parameters = $matches[3];

            foreach ($raw_parameters as $raw_parameter) {
                preg_match_all('!\d+!', $raw_parameter, $int_matches);
//                    var_dump($int_matches);
                $group_id = $int_matches[0][0];
                $grid_settings = get_post_meta($group_id, "o-banner-group", true);
                $banners = get_proper_value($grid_settings, "banners", array());
                foreach ($banners as $banner) {
                    $banner_id = get_proper_value($banner, "banner", FALSE);
                    if ($banner_id) {
                        $this->get_banner_style($banner_id);
                    }
                }
            }
        }
    }

    function get_banner_style($banner_id) {
        $banner_properties = get_post_meta($banner_id, "o-banner", true);

        $skin_class = get_proper_value($banner_properties, "style");
        $skin_obj = new $skin_class(false);
        $skin_properties = $skin_obj->get_properties();

        $banner_style = uie_get_style($banner_id, $banner_properties, $skin_properties);
        echo $banner_style;
    }

}
