<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.orionorigin.com
 * @since             1.0.0
 * @package           Uie
 *
 * @wordpress-plugin
 * Plugin Name:       UI Elements for WordPress
 * Plugin URI:        https://www.orionorigin.com
 * Description:       Useful collection of user interface elements for any wordpress website.
 * Version:           1.0.0
 * Author:            ORION
 * Author URI:        https://www.orionorigin.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       uie
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

define( 'UIE_VERSION', '1.0' );
define( 'UIE_URL', plugins_url('/', __FILE__) );
define( 'UIE_DIR', dirname(__FILE__) );
define( 'UIE_MAIN_FILE', 'ui-elements-for-wp/uie.php' );
define( 'UIE_SKINS_DIR', UIE_DIR . "/skins");
define( 'UIE_SKINS_URL', UIE_URL . "/skins");
define( 'UIE_POST_IMG', UIE_URL . 'admin/images/post-img.jpg');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-uie-activator.php
 */
function activate_uie() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-uie-activator.php';
	Uie_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-uie-deactivator.php
 */
function deactivate_uie() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-uie-deactivator.php';
	Uie_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_uie' );
register_deactivation_hook( __FILE__, 'deactivate_uie' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-uie.php';
require plugin_dir_path(__FILE__) . 'includes/class-uie-banner.php';
require plugin_dir_path(__FILE__) . 'includes/class-uie-banner-group.php';
if(!function_exists("o_admin_fields"))
require plugin_dir_path(__FILE__) . 'includes/utils.php';
require plugin_dir_path(__FILE__) . 'includes/functions.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_uie() {

	$plugin = new Uie();
	$plugin->run();

}
run_uie();
